@@ -1,3 +1,17 @@
+// --------------------------------------------------------------
+// BusOutputArray class
+//
+// adds an output bus to a device
+// outputs "D0" .. "D8" will be added at position 0..7
+//
+// can also add an input bus to the device
+// then, inputs "D0" .. "D8" will be added at position 0..7
+//
+// Andreas Rostin
+// 2003-02-01
+//
+// --------------------------------------------------------------
+
 #ifndef __BUS_OUTPUT_ARRAY__
 #define __BUS_OUTPUT_ARRAY__
 
@@ -7,6 +21,9 @@
 class BusOutputArray
 {
 public:
+	// adds outputs D0..D7 to a device
+	// as_tristate: adds outputs D0..D7 as tristate outputs
+	// i_flag: if true, also adds inputs D0..D7
 	BusOutputArray(XDevice *_dev, bool i_flag, bool as_tristate)
 	{
 		dev = _dev;
@@ -23,23 +40,23 @@ public:
 	{
 		if (!output_id) return -1;
 		for(int i = 0; i < 8; i++)
-			if (output_id == bus_output_id[i])
+			if (output_id == m_aBusOutputId[i])
 				return Tool::pow2(i);
 		return -1;
 	}
 
 	int operator [] (int idx)
 	{
-		return bus_output_id[idx];
+		return m_aBusOutputId[idx];
 	}
 
 private:
 	void initOutputBus(bool as_tristate)
 	{
 		for (int i = 0; i < 8; i++) {
-			bus_output_id[i] = dev->addOutputName(IO_BUS_DATA[i], i + 1);
+			m_aBusOutputId[i] = dev->addOutputName(IO_BUS_DATA[i], i + 1);
 			if (as_tristate)
-				dev->outputSetTristate(bus_output_id[i], true);
+				dev->outputSetTristate(m_aBusOutputId[i], true);
 		}
 	}
 
@@ -52,7 +69,7 @@ private:
 
 	static const QString IO_BUS_DATA[8];	// defined in xdevice.cpp!
 
-	int bus_output_id[8];   // output bus
+	int m_aBusOutputId[8];   // output bus
 
 	XDevice *dev;
 };
