@@ -29,32 +29,35 @@
 #include "deviceOsc.h"
 #include "deviceRAM.h"
 #include "deviceJKFF.h"
+#include "performance.h"
 
 /***************************************************/
 /* methods of Circuit                           */
 /***************************************************/
 int Circuit::instance = 0;
 int Circuit::magic_version = 0;	// to be removed soon!
-DeviceFactory * Circuit::devFactory = DeviceFactory::getInstance();
+DeviceFactory * Circuit::m_poDeviceFactory = DeviceFactory::getInstance();
+int Circuit::m_iCalcCalls = 0;
+int Circuit::m_iPropCalls = 0;
 
-	Circuit::Circuit()
-:XDevice(DeviceType::fNET, 0, 0)
+Circuit::Circuit()
+	:CustomDevice(DeviceType::fNET, QPoint(0,0))
 {
 
 	instance++;
 	m_parent = 0;
 }
 
-	Circuit::Circuit(int x, int y)
-: XDevice(DeviceType::fNET, x, y)
+Circuit::Circuit(const QPoint& oPos)
+	:CustomDevice(DeviceType::fNET, oPos)
 {
 
 	instance++;
 	m_parent = 0;
 }
 
-	Circuit::Circuit(int x, int y, int size)
-: XDevice(DeviceType::fNET, x, y, size)
+Circuit::Circuit(const QPoint& oPos, int iSize)
+	:CustomDevice(DeviceType::fNET, oPos, iSize)
 {
 
 	instance++;
@@ -64,43 +67,35 @@ DeviceFactory * Circuit::devFactory = DeviceFactory::getInstance();
 Circuit::~Circuit()
 {
 	instance--;
+	deleteAll();
+}
 
-	KlogicList<XDevice> *d = netdev.First();
-	KlogicList<XWire> *w = netwire.First();
-	KlogicList<Circuit> *n = netnet.First();
-
-	// destroy all subcircuits
-	while(n) {
-		delete n->Get();
-		netdev.Destroy((XDevice *)(n->Get()));
-		n = n->Next();
-	}
+void Circuit::deleteAll()
+{
 	// destroy all devices
-	while(d) {
-		delete d->Get();
-		d = d->Next();
-	}
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter)
+		delete iter.getDevice();
+	m_oDeviceList.clear();
+
 	// destroy all wires
+	KlogicList<XWire> *w = netwire.First();
 	while(w) {
 		delete w->Get();
 		w = w->Next();
 	}
+
 	// destroy lists
-	netnet.Destroy();
-	netdev.Destroy();
 	netwire.Destroy();
-	netin.Destroy();
-	netout.Destroy();
 
 	initImport();
 }
 
 bool Circuit::hasImpossibleEquations()
 {
-	KlogicList<XDevice> *ld = netdev.First();
-	while(ld) {
-		if (ld->Get()->type() == DeviceType::fRAM || ld->Get()->isTristate()) return true;
-		ld = ld->Next();
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		XDevice *poDevice = iter.getDevice();
+		if (poDevice->type() == DeviceType::fRAM || poDevice->isTristate())
+			return true;
 	}
 	return false;
 }
@@ -108,24 +103,19 @@ bool Circuit::hasImpossibleEquations()
 // returns 1 if all names are unique, otherwise 0
 int Circuit::checkCircuitNames()
 {
-	KlogicList<XDevice> *ld1 = netdev.First();
-	KlogicList<XDevice> *ld2;
-
-	while(ld1) {
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
 		// sub circuits ...
-		Circuit *net = ld1->Get()->devIsCircuit();
-		if (net && !net->checkCircuitNames()) return 0;
+		XDevice *poDevice = iter.getDevice();
+		Circuit *poCircuit = poDevice->devIsCircuit();
+		if (poCircuit && !poCircuit->checkCircuitNames())
+			return 0;
 
 		// devices ...
-		ld2 = netdev.First();
-		while(ld2) {
-			if (ld2->Get() != ld1->Get()) {
-				if (!strcmp(ld1->Get()->getName(), ld2->Get()->getName())) return 0;
-			}
-			ld2 = ld2->Next();
+		for (DeviceList::iterator iter2 = m_oDeviceList.begin(); iter2 != m_oDeviceList.end(); ++iter2) {
+			if (iter2.getDevice() != poDevice)
+				if (!strcmp(poDevice->getName(), iter2.getDevice()->getName()))
+					return 0;
 		}
-
-		ld1 = ld1->Next();
 	}
 	return 1;
 }
@@ -133,28 +123,23 @@ int Circuit::checkCircuitNames()
 // change all duplicate names to be unique
 int Circuit::unifyCircuitNames()
 {
-	KlogicList<XDevice> *ld1 = netdev.First();
-	KlogicList<XDevice> *ld2;
-
-	while(ld1) {
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
 		// sub circuits ...
-		Circuit *net = ld1->Get()->devIsCircuit();
-		if (net && !net->checkCircuitNames()) return 0;
+		XDevice *poDevice = iter.getDevice();
+		Circuit *poCircuit = poDevice->devIsCircuit();
+		if (poCircuit && !poCircuit->unifyCircuitNames())
+			return 0;
 
 		// devices ...
-		ld2 = netdev.First();
-		while(ld2) {
-			if (ld2->Get() != ld1->Get()) {
-				if (!strcmp(ld1->Get()->getName(), ld2->Get()->getName())) {
+		for (DeviceList::iterator iter2 = m_oDeviceList.begin(); iter2 != m_oDeviceList.end(); ++iter2) {
+			if (iter2.getDevice() != poDevice) {
+				if (!strcmp(poDevice->getName(), iter2.getDevice()->getName())) {
 					QString buffer;
-					buffer.sprintf("uni%d", ld2->Get()->getID());
-					setName(ld2->Get()->getID(), buffer);
-				}
+					buffer.sprintf("uni%d", iter2.getDevice()->getID());
+					setName(iter2.getDevice()->getID(), buffer);
+				 }
 			}
-			ld2 = ld2->Next();
 		}
-
-		ld1 = ld1->Next();
 	}
 	return 1;
 }
@@ -164,46 +149,12 @@ void Circuit::getAllEquations(map<QString,OutputInfo>& oEquations, const QString
 	QString sNewPrefix = sQPrefix + getName() + ".";
 	sNewPrefix.replace(QRegExp(" "), "_" );
 
-	KlogicList<XDevice> *ld = netdev.First();
-
-	while(ld) {
-		Device *dev = ld->Get();
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		Device *dev = iter.getDevice();
 		dev->getAllEquations(oEquations, sNewPrefix, bIsolate);
-		ld = ld->Next();
 	}
 }
 
-void Circuit::deleteCircuit(QPainter *p)
-{
-	// destroy all subcircuits
-	KlogicList<Circuit> *n = netnet.First();
-	while(n) {
-		//n->Get()->deleteCircuit(p);
-		delete n->Get();
-		netdev.Destroy((XDevice *)(n->Get()));
-		n = n->Next();
-	}
-	// destroy all devices
-	KlogicList<XDevice> *ld = netdev.First();
-	while(ld) {
-		deleteDevice(p, ld->Get());
-		ld = netdev.First();
-	}
-	// destroy all wires
-	KlogicList<XWire> *lw = netwire.First();
-	while(lw) {
-		deleteWire(lw->Get());
-		lw = netwire.First();
-	}
-	// destroy lists
-	netnet.Destroy();
-	netdev.Destroy();
-	netwire.Destroy();
-	netin.Destroy();
-	netout.Destroy();
-	Device::resetCounter();
-}
-
 Circuit * Circuit::rootParent()
 {
 	Circuit *top;
@@ -223,97 +174,82 @@ Circuit * Circuit::parent()
 	return m_parent;
 }
 
-KlogicList<XDevice> *Circuit::devPointer()
+DeviceList::iterator Circuit::getDeviceIterator()
 {
-	return &netdev;
+	return m_oDeviceList.begin();
+}
+
+DeviceList::iterator Circuit::getDeviceEndIterator()
+{
+	return m_oDeviceList.end();
 }
 
 bool Circuit::empty()
 {
-	if (!netnet.First() && !netdev.First() &&
-			!netwire.First() && !netin.First() && !netout.First())
-		return true;
-	return false;
+	return (!m_oDeviceList.size() && !netwire.First());
 }
 
 void Circuit::applyDefaults()
 {
-	KlogicList<XDevice> *ld = netdev.First();
-	Circuit *net;
-
-	setDelay(Device::defDelay());
-	setInverted(XDevice::isDefInverted());
-	setWidth(XDevice::defWidth());
-	setUndef(Device::defUndefined());
-	invertTrigger(Device::triggerInverted());
-	displayName(XDevice::nameDisplayedGlobal());
+	setDelay(Global::Device::getDelay());
+	setInverted(Global::Device::isInverted());
+	setWidth(Global::Device::getWidth());
+	setUndefinedValue(Global::Device::getUndefinedValue());
+	displayName(Global::Device::isDisplayNames());
 	setImage();
 
-	while(ld) {
-		net = ld->Get()->devIsCircuit();
-		if (net) net->applyDefaults();
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		XDevice *poDevice = iter.getDevice();
+		Circuit *poCircuit = poDevice->devIsCircuit();
+		if (poCircuit) poCircuit->applyDefaults();
 		else {
-			ld->Get()->setDelay(Device::defDelay());
-			ld->Get()->setInverted(XDevice::isDefInverted());
-			ld->Get()->setWidth(XDevice::defWidth());
-			ld->Get()->setUndef(Device::defUndefined());
-			ld->Get()->invertTrigger(Device::triggerInverted());
-			ld->Get()->displayName(XDevice::nameDisplayedGlobal());
-			ld->Get()->setEquation();
-			ld->Get()->parseEquation();
-			setName(ld->Get()->getID(), ld->Get()->getName());
-			ld->Get()->setImage();
-		}
-		ld = ld->Next();
-	}
-}
-
-void Circuit::mapImportID(int old_id, int dev_id)
-{
-	XDevice *devi = netin.Get(dev_id);
-	XDevice *devo = netout.Get(dev_id);
-
-	if (devi) {
-		KlogicList<Value> *lv = named_input.With(old_id);
-		if (lv) {
-			lv->setText(devi->getName());
-			lv->setID1(dev_id);
-		}
-	}
-
-	if (devo) {
-		KlogicList<Calculator> *lop = named_output.With(old_id);
-		if (lop) {
-			lop->setText(devo->getName());
-			lop->setID1(dev_id);
+			poDevice->setDelay(Global::Device::getDelay());
+			poDevice->setInverted(Global::Device::isInverted());
+			poDevice->setWidth(Global::Device::getWidth());
+			poDevice->setUndefinedValue(Global::Device::getUndefinedValue());
+			poDevice->displayName(Global::Device::isDisplayNames());
+			poDevice->setEquation();
+			poDevice->parseEquation();
+			setName(poDevice->getID(), poDevice->getName());
+			poDevice->setImage();
 		}
 	}
 }
 
-void Circuit::setName(int dev_id, const QString& new_text)
+void Circuit::mapImportID(int iOldDeviceID, int iNewDeviceID)
 {
-	XDevice *d = netdev.Get(dev_id);
-	if (d) {
-		d->setName(new_text);
-		if ((d->type() == DeviceType::fIN || d->type() == DeviceType::fOUT) && !new_text.isEmpty() && new_text.length()) {
+	XDevice *poInputDev = m_oInputList[iNewDeviceID];
+	if (poInputDev)
+		mapInputName(iOldDeviceID, iNewDeviceID, poInputDev->getName());
+
+	XDevice *poOutputDev = m_oOutputList[iNewDeviceID];
+	if (poOutputDev)
+		mapOutputName(iOldDeviceID, iNewDeviceID, poOutputDev->getName());
+}
+
+void Circuit::setName(int iDeviceID, const QString& sName)
+{
+	XDevice *poDevice = m_oDeviceList[iDeviceID];
+	if (poDevice) {
+		poDevice->setName(sName);
+		if ((poDevice->type() == DeviceType::fIN || poDevice->type() == DeviceType::fOUT) && !sName.isEmpty() && sName.length()) {
 			// actualize names within circuit image
-			if (d->type() == DeviceType::fIN) {
-				KlogicList<Value> *lv = named_input.With(dev_id);
-				if (lv) lv->setText(new_text);
-				if (!Device::IMPORT_IGNORE_GLOBAL) setImage();
+			if (poDevice->type() == DeviceType::fIN) {
+				if (!m_oNamedInput.setName(iDeviceID, sName))
+					warning("Circuit::setName - no such input");
 			}
-			if (d->type() == DeviceType::fOUT) {
-				KlogicList<Calculator> *lop = named_output.With(dev_id);
-				if (lop) lop->setText(new_text);
-				if (!Device::IMPORT_IGNORE_GLOBAL) setImage();
+			if (poDevice->type() == DeviceType::fOUT) {
+				if (!m_oNamedOutput.setName(iDeviceID, sName))
+					warning("Circuit::setName - no such output");
 			}
+			if (!Device::IMPORT_IGNORE_GLOBAL) setImage();
 		}
 	}
 }
 
-bool Circuit::hasBooleanOutput(int output_id)
+bool Circuit::hasBooleanOutput(int output_id) const
 {
-	map<int, bool>::iterator iter = m_mHasBooleanOutput.find(output_id);
+	map<int, bool>::const_iterator iter = m_mHasBooleanOutput.find(output_id);
 	if (iter != m_mHasBooleanOutput.end())
 		return iter->second;
 	return true;
@@ -348,21 +284,32 @@ void Circuit::drawDev(QPaintDevice *paintd, QPainter *p, XDevice *dev)
 	// erase device and its connected wires
 	dev->erase(p);
 	// redraw all
-	drawAll(paintd, p);
+	draw(paintd, p);
+}
+
+// erase all devices and wires in the net
+void Circuit::erase(QPainter *p)
+{
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter)
+		iter.getDevice()->erase(p);
+
+	KlogicList<XWire> *lw = netwire.First();
+	while(lw) {
+		lw->Get()->erase(p);
+		lw = lw->Next();
+	}
 }
 
 // draw all devices and wires in the net
 // if paintd is NULL then drawing device is a printer
-void Circuit::drawAll(QPaintDevice *paintd, QPainter *p)
+void Circuit::draw(QPaintDevice *paintd, QPainter *p)
 {
-	KlogicList<XDevice> *ld = netdev.First();
-	KlogicList<XWire> *lw = netwire.First();
-
-	while(ld) {
-		if (paintd) ld->Get()->drawImage(paintd, p);
-		else ld->Get()->drawImage(p);
-		ld = ld->Next();
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		if (paintd) iter.getDevice()->drawImage(paintd, p);
+		else iter.getDevice()->drawImage(p);
 	}
+
+	KlogicList<XWire> *lw = netwire.First();
 	while(lw) {
 		if (paintd) {
 			lw->Get()->drawImage(p);
@@ -381,33 +328,28 @@ void Circuit::drawAll(QPaintDevice *paintd, QPainter *p)
 void Circuit::forceOutputChange()
 {
 	Device::forceOutputChange();
-	KlogicList<XDevice> *ld = netdev.First();
-	while(ld) {
-		ld->Get()->forceOutputChange();
-		ld = ld->Next();
-	}
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter)
+		iter.getDevice()->forceOutputChange();
 }
 
 // draw all wires with its actual potential
 // draw all devices with a changed image
-// returns wether a runtime shortcut occured (WSHORT) or not (0)
+// returns wether a runtime shortcut occured (WSHORT)
 int Circuit::drawStatus(QPaintDevice *paintd, QPainter *p)
 {
 	int ret_code = 0;
-	int ret_tmp;
 
 	// some devices like 7S or LED
-	KlogicList<XDevice> *ld = netdev.First();
-	while(ld) {
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
 		// if image changes..
-		if (ld->Get()->setColor()) {
+		if (iter.getDevice()->setColor()) {
 			// ..draw device
-			ld->Get()->drawImage(paintd, p);
+			iter.getDevice()->drawImage(paintd, p);
 		}
-		ld = ld->Next();
 	}
 
 	// draw all wires in color depending of device-output
+	int ret_tmp;
 	KlogicList<XWire> *lw = netwire.First();
 	while(lw) {
 		// if color changes..
@@ -415,7 +357,8 @@ int Circuit::drawStatus(QPaintDevice *paintd, QPainter *p)
 			// ..draw wire
 			lw->Get()->drawImage(p);
 			// .. runtime shortcut detection
-			if (ret_tmp == WSHORT) ret_code = WSHORT;
+			if (ret_tmp == WSHORT)
+				ret_code = WSHORT;
 		}
 		lw = lw->Next();
 	}
@@ -424,14 +367,11 @@ int Circuit::drawStatus(QPaintDevice *paintd, QPainter *p)
 	return ret_code;
 }
 
-void Circuit::setUndef(int undef)
+void Circuit::setUndefinedValue(int iUndefinedValue)
 {
-	KlogicList<XDevice> *ld = netout.First();
-	while(ld) {
-		ld->Get()->setUndef(undef);
-		ld = ld->Next();
-	}
-	Device::setUndef(undef);
+	for (DeviceList::iterator iter = m_oOutputList.begin(); iter != m_oOutputList.end(); ++iter)
+		iter.getDevice()->setUndefinedValue(iUndefinedValue);
+	Device::setUndefinedValue(iUndefinedValue);
 }
 
 //*************************************************************************
@@ -439,43 +379,39 @@ void Circuit::setUndef(int undef)
 //*************************************************************************
 
 // create new device
-XDevice * Circuit::newDevice(int function, int x, int y, int size)
+XDevice * Circuit::newDevice(int iFunction, const QPoint& oPos, int iSize)
 {
-	return devFactory->createDevice(this, function, x, y, size);
+	return m_poDeviceFactory->createDevice(this, iFunction, oPos, iSize);
 }
 
 // add new device
-bool Circuit::setChild(XDevice *dev, bool bImport)
+bool Circuit::addChild(XDevice *dev, bool bImport)
 {
 	int type = dev->type();
 	if (type == DeviceType::fIN || type == DeviceType::fOUT) {
 		QString text = dev->getName();
 		if (type == DeviceType::fIN) {
 			if (!bImport) {
-				if (ADDNAMED_OK > addInputName(text, -1, dev->getID()))
+				if (addInputName(text, -1, dev->getID()) < 0)
 					return false;
 			}
-			netin.Append(dev, dev->getID());
+			m_oInputList.add(dev, dev->getID());
 		}
 		if (type == DeviceType::fOUT) {
 			if (!bImport) {
 				QString text = dev->getName();
-				if (ADDNAMED_OK > addOutputName(text, -1, dev->getID()))
+				if (addOutputName(text, -1, dev->getID()) < 0)
 					return false;
 			}
-			dev->setUndef(undef());
-			netout.Append(dev, dev->getID());
+			dev->setUndefinedValue(getUndefinedValue());
+			m_oOutputList.add(dev, dev->getID());
 		}
 	}
-	if (dev->devIsCircuit())
-		netnet.Append(dev->devIsCircuit(), dev->getID());
-
-	netdev.Append(dev, dev->getID());
+	m_oDeviceList.add(dev, dev->getID());
 
 	return true;
 }
 
-
 // virtual
 // returns pointer to the net-device if device is a net-device
 Circuit * Circuit::devIsCircuit()
@@ -486,47 +422,41 @@ Circuit * Circuit::devIsCircuit()
 // look for a device containing point
 XDevice * Circuit::containsDev(QPoint p)
 {
-	KlogicList<XDevice> *l = netdev.First();
-
-	while(l) {
-		if (l->Get()->contains(p))
-			return l->Get();
-		l  = l->Next();
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		if (iter.getDevice()->contains(p))
+			return iter.getDevice();
 	}
-	return (XDevice *)NULL;
+	return 0;
 }
 
 // look for a device containing device
 XDevice * Circuit::containsDev(XDevice *dev)
 {
-	KlogicList<XDevice> *l = netdev.First();
-
-	while(l) {
-		if (l->Get() != dev) {
-			if (l->Get()->contains(dev->getPos())) {
-				return l->Get();
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		XDevice *poDevice = iter.getDevice();
+		if (poDevice != dev) {
+			if (poDevice->contains(dev->getPos())) {
+				return poDevice;
 			}
 		}
-		l  = l->Next();
 	}
-	return (XDevice *)NULL;
+	return 0;
 }
 
 // mark all devices in rect as selected
 void Circuit::selectDev(QRect r, KlogicList<XDevice> *d)
 {
-	KlogicList<XDevice> *l = netdev.First();
-
-	while(l) {
-		if (l->Get()->contains(r)) {
-			if (!d->With(l->Get())) d->Append(l->Get());
-			l->Get()->select(true);
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		XDevice *poDevice = iter.getDevice();
+		if (poDevice->contains(r)) {
+			if (!d->With(poDevice))
+				d->Append(poDevice);
+			poDevice->select(true);
 		}
 		else {
-			d->Destroy(l->Get());
-			l->Get()->select(false);
+			d->Destroy(poDevice);
+			poDevice->select(false);
 		}
-		l = l->Next();
 	}
 }
 
@@ -534,13 +464,13 @@ void Circuit::selectDev(QRect r, KlogicList<XDevice> *d)
 // add all selected devices to the selection (paste operation)
 void Circuit::grabSelection(Selection *sel)
 {
-	KlogicList<XDevice> *ld = netdev.First();
-	KlogicList<XWire> *lw = netwire.First();
-
-	while(ld) {
-		if (ld->Get()->isSelected()) sel->add(ld->Get());
-		ld = ld->Next();
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		XDevice *poDevice = iter.getDevice();
+		if (poDevice->isSelected())
+			sel->add(poDevice);
 	}
+
+	KlogicList<XWire> *lw = netwire.First();
 	while(lw) {
 		if (lw->Get()->isSelected()) sel->add(lw->Get());
 		lw = lw->Next();
@@ -551,26 +481,17 @@ void Circuit::grabSelection(Selection *sel)
 void Circuit::deleteDevice(QPainter *p, XDevice *dev)
 {
 	if (dev->type() == DeviceType::fIN) {
-		netin.Destroy(dev);
+		m_oInputList.remove(dev->getID());
 		removeInputName(dev->getID());
 	}
 	if (dev->type() == DeviceType::fOUT) {
-		netout.Destroy(dev);
+		m_oOutputList.remove(dev->getID());
 		removeOutputName(dev->getID());
 	}
 
 	// erase bitmap from screen
 	dev->erase(p);
-
-	// delete device reference in list
-	Circuit *net = dev->devIsCircuit();
-	if (net) {
-		net->deleteCircuit(p);
-		netnet.Destroy(net);
-	}
-	netdev.Destroy(dev);
-
-	// delete device, in destructor: delete connections
+	m_oDeviceList.remove(dev->getID());
 	delete dev;
 }
 
@@ -642,19 +563,17 @@ int Circuit::removeNode(QPainter *p, QPoint pt)
 // connections will be made automaticly on active node of wire
 int Circuit::checkConnection(XWire *w)
 {
-	KlogicList<XDevice> *ld = netdev.First();
-	KlogicList<XWire> *lw = netwire.First();
 	int ret;
 
 	// look for device connection/disconnection
-	while(ld) {
-		if (DOK != (ret = ld->Get()->checkConnection(w))) {
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		if (DOK != (ret = iter.getDevice()->checkConnection(w))) {
 			w->setColor(true);
 			return ret;
 		}
-		ld = ld->Next();
 	}
 	// look for wire connection/disconnection
+	KlogicList<XWire> *lw = netwire.First();
 	while(lw) {
 		if (w != lw->Get()) {
 			if (WOK != (ret = lw->Get()->checkConnection(w))) {
@@ -671,13 +590,14 @@ int Circuit::checkConnection(XWire *w)
 // (used as import-method only)
 int Circuit::checkConnection(int devid, int inverted, XWire *w)
 {
-	XDevice *d = netdev.Get(devid);
-	int ret;
+	XDevice *poDevice = m_oDeviceList[devid];
+	if (!poDevice)
+		return NFAIL;
+
+	int iRet = poDevice->checkConnection(w, inverted);
+	if (iRet != DOK)
+		return iRet;
 
-	// look for new device connection
-	if (d) {
-		if (DOK != (ret = d->checkConnection(w, inverted))) return ret;
-	}
 	return NFAIL;
 }
 
@@ -772,77 +692,72 @@ void Circuit::deleteWire(XWire *w)
 // set net to init-state (flush all calculation-fifos)
 void Circuit::flush()
 {
-	KlogicList<XDevice> *ld = netdev.First();
-	while(ld) {
-		ld->Get()->flush(0);
-		ld = ld->Next();
-	}
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter)
+		iter.getDevice()->flush(0);
 }
 
-// calculate burst (normally bust is 1)
+// calculate burst
+// usually, burst will be 1 that means single calculation and propagation
+// delays are reduced until no delay is left when burst is greater than 1
 void Circuit::Burst(int burst)
-{	int burst_step;
-
-	switchInterface(IF_INPUT);
-
-	// calculate new values
-	for (burst_step = 0; burst_step < burst; burst_step++) {
+{
+/*
+	Performance p;
+	m_iCalcCalls = 0;
+	m_iPropCalls = 0;
+	p.start();
+*/
+	// calculate circuit <burst> times
+	for (int burst_step = 0; burst_step < burst; ++burst_step) {
 		Calculate(burst_step);
 		Propagate(burst_step);
 	}
-
-	switchInterface(IF_OUTPUT);
+/*
+	p.end();
+	cout << "measurement complete:" << endl;
+	cout << "\t" << m_iCalcCalls << " calls to ::Calculate" << endl;
+	cout << "\t" << m_iPropCalls << " calls to ::Propagate" << endl;
+	cout << "\t" << "time (ms) " << p.getMilliSeconds() << endl;
+*/
 }
 
 // switch input- or output devices of this
 void Circuit::switchInterface(int if_type)
 {
-	KlogicList<XDevice> *ld;
-	KlogicList<Circuit> *ln;
-
 	// set output-values of input-devices by requesting named inputs of this sub circuit
 	// input devices are part of this, and connected to named inputs of this
 	if (if_type == IF_INPUT) {
-		ld = netin.First();
-		while(ld) {
-			XDevice *oInputDev = ld->Get();
+		for (DeviceList::iterator iter = m_oInputList.begin(); iter != m_oInputList.end(); ++iter) {
+			XDevice *oInputDev = iter.getDevice();
 			// set input device from the named input value
 			bool bIsBoolean;
 			int iVal = input(oInputDev->getID(), bIsBoolean);
-			oInputDev->setStaticInput(iVal);
+			oInputDev->setInputValue(iVal);
 			oInputDev->setHasBooleanOutput(0, bIsBoolean);
-			ld = ld->Next();
 		}
 	}
 
 	// set output values of named outputs by requesting output devices
 	// output devices are part of this, and named outputs are connected to them
 	if (if_type == IF_OUTPUT) {
-		ld = netout.First();
-		while (ld) {
-			XDevice *oOutputDev = ld->Get();
+		for (DeviceList::iterator iter = m_oOutputList.begin(); iter != m_oOutputList.end(); ++iter) {
+			XDevice *oOutputDev = iter.getDevice();
 			// set the named output value from output device
-			setStaticOutput(oOutputDev->getID(), oOutputDev->output());
+			setOutputValue(oOutputDev->getID(), oOutputDev->output());
 			setHasBooleanOutput(oOutputDev->getID(), oOutputDev->hasBooleanOutput(0));
-			ld = ld->Next();
 		}
 	}
-
-	ln = netnet.First();
-	while(ln) {
-		ln->Get()->switchInterface(if_type);
-		ln = ln->Next();
-	}
 }
 
 // virtual
 // calculate all devices of this circuit and all sub circuits
 void Circuit::Calculate(int burst_step)
 {
-	KlogicList<XDevice> *ld = netdev.First();
-	while(ld) {
-		ld->Get()->Calculate(burst_step);       // recursive by virtual
-		ld = ld->Next();
+	m_iCalcCalls++;
+	switchInterface(IF_INPUT);
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		m_iCalcCalls++;
+		iter.getDevice()->Calculate(burst_step);       // recursive by virtual
 	}
 }
 
@@ -850,12 +765,12 @@ void Circuit::Calculate(int burst_step)
 // propagate values to the outputs of this circuit and all sub circuits
 void Circuit::Propagate(int burst_step)
 {
-	KlogicList<XDevice> *ld;
-	ld = netdev.First();
-	while(ld) {
-		ld->Get()->Propagate(burst_step);	// recursive by virtual
-		ld = ld->Next();
+	m_iPropCalls++;
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		m_iPropCalls++;
+		iter.getDevice()->Propagate(burst_step);	// recursive by virtual
 	}
+	switchInterface(IF_OUTPUT);
 }
 
 /***************************************************/
@@ -908,27 +823,24 @@ bool Circuit::exportXML(QTextStream *ts, XmlNet *net, bool selected, int level,
 	}
 
 	// circuit devices
-	KlogicList<XDevice> *ld = netdev.First();
-	Circuit *pNet;
-	while(ld) {
-		pNet = ld->Get()->devIsCircuit();
-		if (pNet) {
-			XmlNet subCircuit(pNet, selected, level, dx, dy);
+	for (DeviceList::iterator iter = m_oDeviceList.begin(); iter != m_oDeviceList.end(); ++iter) {
+		Circuit *poCircuit = iter.getDevice()->devIsCircuit();
+		if (poCircuit) {
+			XmlNet subCircuit(poCircuit, selected, level, dx, dy);
 			if (subCircuit.isValid()) {
 				// for sub-circuits always set selected=false!
-				pNet->exportXML(ts, &subCircuit, false, level, 0, 0);	// recursion!
+				poCircuit->exportXML(ts, &subCircuit, false, level, 0, 0);	// recursion!
 
 				// add net content (if ts avail: content already added)
 				if (!ts) net->addContent(subCircuit.getField());
 			}
 		} else {
-			XmlDevice dev(ld->Get(), selected, level, dx, dy);
+			XmlDevice dev(iter.getDevice(), selected, level, dx, dy);
 			if (dev.isValid()) {
 				if (ts) *ts << dev.getField();
 				else net->addContent(dev.getField());
 			}
 		}
-		ld = ld->Next();
 	}
 
 	// circuit wire <-> wire connections
@@ -966,56 +878,3 @@ bool Circuit::exportXML(QTextStream *ts, XmlNet *net, bool selected, int level,
 	return true;
 }
 
-// proprietary export format, recursively called!
-// subnet is true for the very first circuit, if a sub circuit should be stored
-// for all lower circuits, subnet is always true!
-bool Circuit::exportNet(QTextStream &ts, bool selected, bool subnet, int dx, int dy)
-{
-	QString s;
-
-	if (subnet) ts << IO_B_SUBNET << "\n";
-	else ts << IO_B_NET << "\n";
-
-	ts << exportInstance() << "\n";
-
-	// write wire position information
-	ts << IO_B_WIRE << "\n";
-	s = exportWires(selected, dx, dy);
-	if (!s.isEmpty()) ts << s << "\n";
-	ts << IO_E_WIRE << "\n";
-
-	// write device type/position information
-	ts << IO_B_DEVICE << "\n";
-	s = exportDevices(selected, dx, dy);
-	if (!s.isEmpty()) ts << s << "\n";
-	ts << IO_E_DEVICE << "\n";
-
-	// write subnet information
-	KlogicList<Circuit> *ln = netnet.First();
-	while(ln) {
-		if ((selected && ln->Get()->isSelected()) || !selected) {
-			if (!ln->Get()->exportNet(ts, false, true, 0, 0)) {
-				return false;
-			}
-		}
-		ln = ln->Next();
-	}
-
-	// write wire-wire connections
-	ts << IO_B_CONNWIRE << "\n";
-	s = exportWireConn(selected, dx, dy);
-	if (!s.isEmpty()) ts << s << "\n";
-	ts << IO_E_CONNWIRE << "\n";
-
-	// write wire-device connections
-	ts << IO_B_CONNDEVICE << "\n";
-	s = exportDevConn(selected, dx, dy);
-	if (!s.isEmpty()) ts << s << "\n";
-	ts << IO_E_CONNDEVICE << "\n";
-
-	if (subnet) ts << IO_E_SUBNET << "\n";
-	else ts << IO_E_NET << "\n";
-
-	return true;
-}
-
