@@ -15,8 +15,8 @@ class QMainWindow;
 class ClientW : public QFrame
 {	Q_OBJECT
 public:
-	ClientW(MainWidget *, const char *file);
-	ClientW(MainWidget *, XDeviceNet *);
+	ClientW(MainWidget *, const QString& sFile);
+	ClientW(MainWidget *, Circuit *);
 	ClientW(QFrame *, int);
 	~ClientW();
 
@@ -29,27 +29,26 @@ public slots:
 	void vScroll(int);
 	void up();
 	void netChange(int);
-
-signals:
-	void visibleChanged(QRect);
+	void autoMove(const QPoint&);
 
 private:
-	void commonConstruct();
+	void initFrame();
+	void initPosition();
 	void keyPressEvent(QKeyEvent *);
 	void paintEvent(QPaintEvent *);
 	void setWidgets();
 
-	bool main_client;
+	bool m_bIsClient;	// not the main window?
 
-	QScrollBar *hscroll;
-	QScrollBar *vscroll;
+	QScrollBar *m_poHScroll;
+	QScrollBar *m_poVScroll;
 
-	QFrame *netframe;
-	NetWidget *netwidget;
-	MainWidget *mainwidget;
-	QToolBar *toolbar;
-	QRect logicBase;
-	QRect logicPos;
-	XDeviceNet *m_devnet;
+	QFrame *m_poCircuitFrame;
+	NetWidget *m_poCircuitWidget;
+	MainWidget *m_poMainWidget;
+	QToolBar *m_poToolbar;
+	QRect m_oBorder;
+	QRect m_oCircuitPos;
+	Circuit *m_poCircuit;
 };
 #endif
