@@ -1,6 +1,8 @@
 #ifndef KLOGIC_DEV_FACTORY
 #define KLOGIC_DEV_FACTORY
 
+#include <qpoint.h>
+
 class XDevice;
 
 class DeviceFactory
@@ -12,7 +14,7 @@ public:
 		return m_pInstance;
 	}
 
-	XDevice *createDevice(XDevice *, int function, int x, int y, int import_size = -1);
+	XDevice *createDevice(XDevice *, int iFunction, const QPoint& oPos, int iSize = -1);
 
 private:
 	DeviceFactory() {}
