@@ -20,8 +20,8 @@
 class DeviceInterface : public Device
 {
 public:
-	DeviceInterface(int function, int delay = -1, int undefined = -1, int clock = -1)
-		:Device(function, delay, undefined, clock)
+	DeviceInterface(int iFunction)
+		:Device(iFunction)
 	{
 	}
 
@@ -29,19 +29,6 @@ public:
 	{
 	}
 
-	// -----------------------------------------------------
-	// retrieve device pointer: cast needed!
-	// -----------------------------------------------------
-	virtual void * getInstance()
-	{
-		return (void *)this;
-	}
-
-	virtual bool sizeChangeable()
-	{
-		return false;
-	}
-
 	// -----------------------------------------------------
 	// Oscillator device
 	// -----------------------------------------------------
@@ -51,6 +38,8 @@ public:
 	virtual void setOszOff(int) {}
 	virtual int getCurrOszStep() { return 0; }
 	virtual void setCurrOszStep(int) {}
+	virtual void setOscType(int) {}
+	virtual int getOscType() const { return 0; }
 
 	// -----------------------------------------------------
 	// RAM device
@@ -73,7 +62,7 @@ public:
 	virtual bool isToggle() const { return false; }
 	virtual void setToggle(bool) {}
 	virtual void toggleStaticInput() {}
-	virtual void setStaticInput(int) {}
+	virtual void setInputValue(int) {}
 
 	// -----------------------------------------------------
 	// IO device, Switch device
@@ -82,8 +71,18 @@ public:
 	virtual bool isInteractive() { return false; }
 	virtual void setHasBooleanOutput(int, bool) {}
 
+	// -----------------------------------------------------
+	// all FF devices
+	// -----------------------------------------------------
+	virtual void setClock(Global::Device::CLOCKTYPE) {}
+	virtual Global::Device::CLOCKTYPE clock() const { return Global::Device::CLK_NONE; }
+	virtual bool hasClock() const { return false; }
+	virtual bool hasMaster() const { return false; }
+	virtual void setMaster(bool) {}
+
 	// common
-	virtual void setUndef(int val) { Device::setUndef(val); };
+	virtual void setUndefinedValue(int val) { Device::setUndefinedValue(val); }
+	virtual void setEquation() {}
 protected:
 
 private:
