@@ -18,9 +18,11 @@
 class BusDevice : public XDevice
 {
 public:
-	BusDevice(int x, int y, int size = -1, int = -1, int undef = -1, int clock = -1)
-		: XDevice(DeviceType::fBUS, x, y, size, 0, undef, clock)
+	BusDevice(const QPoint& oPos, int size = -1)
+		: XDevice(DeviceType::fBUS, oPos, size)
 	{
+		if (size == -1)
+			XDevice::setSize(8);
 	}
 
 	virtual ~BusDevice()
@@ -30,15 +32,14 @@ public:
 	// not in use .. (constructor)
 	virtual void init()
 	{
-		setMux(false);	// fan in
-		XDevice::setSize(8);
-
+		setMux(false);	// fan in per default
 		XDevice::init();
 	}
 
 	virtual void setMux(bool flag)
 	{
-		mux_mode = flag;
+		m_bMuxMode = flag;
+		m_oImageKey.setDevType(m_bMuxMode);
 		setImage();
 		setEquation();
 		parseEquation();
@@ -46,35 +47,29 @@ public:
 
 	virtual bool isMux()
 	{
-		return mux_mode;
+		return m_bMuxMode;
 	}
 
-	virtual bool hasBooleanOutput(int)
+	virtual bool hasBooleanOutput(int) const
 	{
-		return mux_mode;
+		return m_bMuxMode;
 	}
 
-	virtual bool setSize(int new_size)
+	virtual bool setSize(int iSize)
 	{
-		bool retval = XDevice::setSize(new_size);
+		bool retval = XDevice::setSize(iSize);
 		setEquation();
 		parseEquation();
 		return retval;
 	}
 
-	virtual void * getInstance()
-	{
-		return (void *)this;
-		
-	}
-
 	virtual void setEquation()
 	{
 		KlogicList<OutputInfo> output_list;
 		KlogicList<OutputInfo> *ls;
 
 		// create list with needed equations
-		if (mux_mode) {
+		if (m_bMuxMode) {
 			// -----------------------------------------------
 			// multiplexing mode (fan out): single input, many output
 			// -----------------------------------------------
@@ -87,7 +82,7 @@ public:
 				oi->equation = "DI % ";	// bit operator (OP_BIT)
 				oi->equation += QString::number(i);
 
-				oi->output_type = Device::FINAL_OUTPUT;
+				oi->output_type = Global::Device::FINAL_OUTPUT;
 
 				ls = output_list.Append(oi);
 				ls->setText(oi->output_name);
@@ -100,7 +95,7 @@ public:
 			OutputInfo *oi = new OutputInfo;
 			oi->output_name.sprintf("DO");
 			oi->output_id = getOutputID(oi->output_name);
-			oi->output_type = Device::FINAL_OUTPUT;
+			oi->output_type = Global::Device::FINAL_OUTPUT;
 
 			QString input;
 			for(int i = 0; i < size(); i++) {
@@ -128,37 +123,28 @@ public:
 		}
 	}
 
-	virtual bool hasClock()
-	{
-		return false;
-	}
-
-	virtual bool hasNamedInput()
+	virtual bool hasNamedInput() const
 	{
 		return true;
 	}
 
-	virtual bool hasNamedOutput()
+	virtual bool hasNamedOutput() const
 	{
 		return true;
 	}
 
-	virtual bool sizeChangeable()
+	virtual Image * createImage(const ImageKey& oKey)
 	{
-		return true;
-	}
-
-	virtual void setImage()
-	{	QPixmap *pic = getImage();
+		Image *poImage = m_oImageCache.getNewImage();
 		QPainter p;
 		QPoint pt(0,0);
 		int width = 21;
 
 		// resize image first, erase everything
-		pic->resize(width, 6 + ((deviceSize - 1) * Grid::GRID));
-		pic->fill();
+		poImage->resize(width, 6 + ((size() - 1) * Grid::GRID));
+		poImage->fill();
 
-		p.begin(pic);
+		p.begin(poImage);
 
 		// top of the device
 		pt.setY(pt.y() + 3);
@@ -166,12 +152,12 @@ public:
 		// body
 		p.setPen(Qt::black);
 		p.setBrush(Qt::black);
-		p.drawRect(8, 0, width - 17, deviceSize * Grid::GRID);
+		p.drawRect(8, 0, width - 17, size() * Grid::GRID);
 
 		// input/output lines
-		if (mux_mode) {
+		if (oKey.getDevType()) {
 			// one input, many output
-			for(int i = 0; i < deviceSize; i++) {
+			for(int i = 0; i < size(); i++) {
 
 				// input line
 				if (!i) p.drawLine(3, pt.y(), 8, pt.y());
@@ -182,7 +168,7 @@ public:
 			}
 		} else {
 			// many input, one output
-			for(int i = 0; i < deviceSize; i++) {
+			for(int i = 0; i < size(); i++) {
 				// output line
 				if (!i) p.drawLine(width - 9, pt.y(), width - 3, pt.y());
 				// input line
@@ -191,11 +177,8 @@ public:
 				pt.setY(pt.y() + Grid::GRID);
 			}
 		}
-
-		drawConnectionLines(&p);
-		XObject::setImage();
-
 		p.end();
+		return poImage;
 	}
 
 	virtual void printImage(QPainter *, const QRect &)
@@ -209,7 +192,7 @@ public:
 
 private:
 	// type of bus: multiplexer or demultiplexer
-	bool mux_mode;
+	bool m_bMuxMode;
 };
 
 #endif
