@@ -21,22 +21,25 @@ public:
 	static const int fRS = 1008;
 	static const int fDFF = 1009;
 	static const int fJK = 1010;
-	static const int fLEDgreen = 1011;
+	static const int fLED = 1011;
 	static const int fIN = 1012;
 	static const int fOUT = 1013;
 	static const int fNET = 1014;
 	static const int fPWR = 1015;
 	static const int fTXT = 1016;
 	static const int fEQU = 1017;
-	static const int fLEDred = 1018;
-	static const int fLEDblue = 1019;
-	static const int fLEDyellow = 1020;
+	static const int fLED1 = 1018;
+	static const int fLED2 = 1019;
+	static const int fLED3 = 1020;
 	static const int fTRI = 1021;
 	static const int fRAM = 1022;
 	static const int fBUS = 1023;
-	static const int fMATRIX = 1024;
+	static const int fMATRIX = 1024;	// not active - difficult to implement
+	static const int fTFF = 1025;
+	static const int fNAND = 1026;		// fAND is used!
+	static const int fNOR = 1027;		// fOR is used!
 
-	static const int TYPE_CNT = 25;	// no of entries above!
+	static const int TYPE_CNT = 26;	// no of entries above!
 
 	static const int fFIRST_LIBDEV = 2000;
 	static const int fLAST_LIBDEV = 2999;
