@@ -8,7 +8,7 @@ class QPushButton;
 class QRadioButton;
 class QButtonGroup;
 class QString;
-#include<symbolOpStack.h>
+#include<symbolicCalc.h>
 
 class KarnaughWidget : public QWidget
 {
@@ -20,22 +20,15 @@ public:
 private:
 	void paintEvent(QPaintEvent *);
 	void drawKarnaugh();
-	void drawTable();
+	bool drawTable();
 	void drawQuadTable(int, int);
-	void getCoord(int *, int *, int *);
+	void getCoord(const Pattern& oPat, int&, int&);
 	void drawPattern();
 	void drawGroups();
 
-	SymbolOpStack op;
+	SymbolicCalc m_oSymCalc;
 
-        char **input_list;
-        int input_cnt;
-        int **pattern;
-        int pattern_cnt;
-
-	int **group;
-	int *group_size;
-	int group_cnt;
+	int m_iSize;
 };
 
 class DlgPattern : public QDialog
