@@ -1,11 +1,11 @@
 #ifndef __FIFO_CLASS__
 #define __FIFO_CLASS__
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
+#include <list>
 
-class Fifo
+using namespace std;
+
+class Fifo: private list<int>
 {
 public:
 	static int instance;
@@ -15,11 +15,10 @@ public:
 	int put(int);
 	int get();
 	void setDelay(int);
-	int delay();
+	int getDelay();
 	void flush(int);
 private:
-	int *_fifo;
-	int _depth;
+	int m_iDepth;
 };
 
 #endif
