@@ -313,8 +313,6 @@ void MainWidget::initToolbar()
 	gate_toolbar->hideItem(DeviceType::fOUT);
 
 	gate_toolbar->setBarPos(KToolBar::Top);
-	gate_toolbar->enable(KToolBar::Show);
-
 	addToolBar(gate_toolbar);
 	gate_toolbar->show();
 
@@ -383,8 +381,6 @@ void MainWidget::initToolbar()
 	connect(speed_slider, SIGNAL(sliderMoved(int)), this, SLOT(simTimeSliderChanged(int)));
 
 	sim_toolbar->setBarPos(KToolBar::Top);
-	sim_toolbar->enable(KToolBar::Show);
-
 	addToolBar(sim_toolbar);
 	sim_toolbar->show();
 	tool_visible = 1;
@@ -1155,7 +1151,7 @@ void MainWidget::netDelete(Circuit *delnet)
 		old_client_widget = lc->Get();
 		if (oldnet->contained(delnet)) {
 			lc = lc->Next();		// will become invalid on next call!!!
-			old_client_widget->closeEvent((QCloseEvent *)NULL);
+			old_client_widget->close(TRUE);
 		} else {
 			lc = lc->Next();
 		}
