@@ -126,10 +126,10 @@ NetWidget::NetWidget(QWidget *hparent, QWidget *parent) : QFrame(hparent)
 	setFrameStyle( QFrame::Panel | QFrame::Raised );
 	resize(Global::Screen::VIRT_SCREEN_SIZE_X, Global::Screen::VIRT_SCREEN_SIZE_Y);                  // set default size in pixels
 
-	activeNet = new Circuit();
-	activeDev = (XDevice *)NULL;
-	activeWire = (XWire *)NULL;
-	activeSelection = new Selection();
+	m_poActiveCircuit = new Circuit();
+	m_poActiveDevice = (XDevice *)NULL;
+	m_poActiveWire = (XWire *)NULL;
+	m_poActiveSelection = new Selection();
 	m_oParent = parent;
 
 	// drawing mode
@@ -170,10 +170,10 @@ NetWidget::NetWidget(QWidget *hparent, QWidget *parent, Circuit *net)
 	setFrameStyle( QFrame::Panel | QFrame::Raised );
 	resize(Global::Screen::VIRT_SCREEN_SIZE_X, Global::Screen::VIRT_SCREEN_SIZE_Y);                // set default size in pixels
 
-	activeNet = net;
-	activeDev = (XDevice *)NULL;
-	activeWire = (XWire *)NULL;
-	activeSelection = new Selection();
+	m_poActiveCircuit = net;
+	m_poActiveDevice = (XDevice *)NULL;
+	m_poActiveWire = (XWire *)NULL;
+	m_poActiveSelection = new Selection();
 	m_oParent = hparent;
 
 	// device to drop when in drop-mode
@@ -206,8 +206,8 @@ NetWidget::~NetWidget()
 {
 	if (client) return;
 
-	delete activeNet;
-	delete activeSelection;
+	delete m_poActiveCircuit;
+	delete m_poActiveSelection;
 }
 
 void NetWidget::mousePressEvent( QMouseEvent *e )
@@ -222,15 +222,15 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 		if (MainWidget::getMode() == MainWidget::MAIN_MODE_DRAW) {
 			// device clicked? set active device
 			// devices have priority - since we have bus devices
-			activeDev = activeNet->containsDev(e->pos());
-			if (activeDev) {
-				activeDev->setOrigin();
+			m_poActiveDevice = m_poActiveCircuit->containsDev(e->pos());
+			if (m_poActiveDevice) {
+				m_poActiveDevice->setOrigin();
 
 				// if device is a push button device,  toggle its status
-				if (activeDev->isInteractive() && activeDev->isToggle()) {
-					activeDev->toggleStaticInput();
+				if (m_poActiveDevice->isInteractive() && m_poActiveDevice->isToggle()) {
+					m_poActiveDevice->toggleStaticInput();
 					p.begin(this);
-					activeNet->drawAll(this, &p);
+					m_poActiveCircuit->draw(this, &p);
 					p.end();
 				}
 
@@ -238,35 +238,35 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 			}
 
 			// wire clicked? set active wire
-			activeWire = activeNet->containsWire(e->pos());
-			if (activeWire) {
+			m_poActiveWire = m_poActiveCircuit->containsWire(e->pos());
+			if (m_poActiveWire) {
 				return;
 			}
 
 			// nothing clicked? new wire
 			p.begin(this);
-			activeWire = activeNet->newWire(&p, e->pos());
+			m_poActiveWire = m_poActiveCircuit->newWire(&p, e->pos());
 			p.end();
-			if (activeWire) {
+			if (m_poActiveWire) {
 				emit netContentChanged();
 				return;
 			}
 		}
 		if (MainWidget::getMode() == MainWidget::MAIN_MODE_DROP) {
 			// move device
-			activeDev = activeNet->containsDev(e->pos());
-			if (activeDev) {
-				activeDev->setOrigin();
+			m_poActiveDevice = m_poActiveCircuit->containsDev(e->pos());
+			if (m_poActiveDevice) {
+				m_poActiveDevice->setOrigin();
 
 				// if device is a push button device,  toggle its status
-				if (activeDev->isInteractive() && activeDev->isToggle()) {
-					activeDev->toggleStaticInput();
+				if (m_poActiveDevice->isInteractive() && m_poActiveDevice->isToggle()) {
+					m_poActiveDevice->toggleStaticInput();
 					p.begin(this);
-					activeNet->drawAll(this, &p);
+					m_poActiveCircuit->draw(this, &p);
 					p.end();
 				} else {
 					p.begin(this);
-					activeNet->drawDev(this, &p, activeDev);
+					m_poActiveCircuit->drawDev(this, &p, m_poActiveDevice);
 					p.end();
 
 					// redraw client widgets with the same content as this
@@ -276,100 +276,100 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 				return;
 			}
 			// create new device
-			activeDev = activeNet->newDevice(actualDevFunc, e->pos().x(), e->pos().y());
-			if (!activeDev && (actualDevFunc == DeviceType::fIN)) {
+			m_poActiveDevice = m_poActiveCircuit->newDevice(actualDevFunc, e->pos());
+			if (!m_poActiveDevice && (actualDevFunc == DeviceType::fIN)) {
 				QMessageBox::warning(m_oParent, i18n("device failure"), i18n("unable to add more named inputs\nresize this sub circuit"));
 				emit netContentChanged();
 				changed = true;
 				return;
 			}
-			if (!activeDev && (actualDevFunc == DeviceType::fOUT)) {
+			if (!m_poActiveDevice && (actualDevFunc == DeviceType::fOUT)) {
 				QMessageBox::warning(m_oParent, i18n("device failure"), i18n("unable to add more named outputs\nresize this sub circuit"));
 				emit netContentChanged();
 				changed = true;
 				return;
 			}
-			if (!activeDev) {
+			if (!m_poActiveDevice) {
 				QMessageBox::warning(m_oParent, i18n("device failure"), i18n("panic: cannot create device!"));
 				return;
 			}
-			if (activeNet->containsDev(activeDev)) {
+			if (m_poActiveCircuit->containsDev(m_poActiveDevice)) {
 				deleteDev(0);
 				emit netContentChanged();
 				changed = true;
 				return;
 			}
-			activeDev->setOrigin();
+			m_poActiveDevice->setOrigin();
 			p.begin(this);
-			activeNet->drawDev(this, &p, activeDev);
+			m_poActiveCircuit->drawDev(this, &p, m_poActiveDevice);
 			p.end();
 			emit netContentChanged();
-			if (activeDev->drawGraph() && activeDev->graphEnabled())
+			if (m_poActiveDevice->drawGraph() && m_poActiveDevice->graphEnabled())
 				emit graphChanged();
 			return;
 		}
 		if (MainWidget::getMode() == MainWidget::MAIN_MODE_SELECT) {
-			if (activeSelection->getStatus() == SEL_EXISTS && activeSelection->onFrame(e->pos())) {
+			if (m_poActiveSelection->getStatus() == SEL_EXISTS && m_poActiveSelection->onFrame(e->pos())) {
 				// selection move mode
-				activeSelection->beginMove(e->pos());
-			} else if (activeSelection->getStatus() == SEL_EXISTS &&  NULL != (activeDev = activeNet->containsDev(e->pos()))) {
-				if (activeSelection->contains(activeDev)) {
+				m_poActiveSelection->beginMove(e->pos());
+			} else if (m_poActiveSelection->getStatus() == SEL_EXISTS &&  NULL != (m_poActiveDevice = m_poActiveCircuit->containsDev(e->pos()))) {
+				if (m_poActiveSelection->contains(m_poActiveDevice)) {
 					// selection move mode
-					activeSelection->beginMove(e->pos());
+					m_poActiveSelection->beginMove(e->pos());
 				} else {
 					// select device, then selection move mode
-					activeSelection->addTemp(activeDev);
-					activeSelection->beginMove(e->pos());
+					m_poActiveSelection->addTemp(m_poActiveDevice);
+					m_poActiveSelection->beginMove(e->pos());
 					p.begin(this);
-					activeSelection->erase(&p);
-					activeNet->drawAll(this, &p);
-					activeSelection->draw(&p);
+					m_poActiveSelection->erase(&p);
+					m_poActiveCircuit->draw(this, &p);
+					m_poActiveSelection->draw(&p);
 					p.end();
 				}
 			} else {
 				// new selection?
-				activeSelection->setNet(activeNet);
+				m_poActiveSelection->setNet(m_poActiveCircuit);
 
 				// select/deselect single device
-				activeDev = activeNet->containsDev(e->pos());
-				if (activeDev) {
-					if (activeSelection->contains(activeDev)) activeSelection->remove(activeDev);
-					else activeSelection->add(activeDev);
-					activeDev = (XDevice *)NULL;
-					activeWire = (XWire *)NULL;
+				m_poActiveDevice = m_poActiveCircuit->containsDev(e->pos());
+				if (m_poActiveDevice) {
+					if (m_poActiveSelection->contains(m_poActiveDevice)) m_poActiveSelection->remove(m_poActiveDevice);
+					else m_poActiveSelection->add(m_poActiveDevice);
+					m_poActiveDevice = (XDevice *)NULL;
+					m_poActiveWire = (XWire *)NULL;
 					p.begin(this);
-					activeSelection->erase(&p);
-					activeNet->drawAll(this, &p);
-					activeSelection->draw(&p);
+					m_poActiveSelection->erase(&p);
+					m_poActiveCircuit->draw(this, &p);
+					m_poActiveSelection->draw(&p);
 					p.end();
 					return;
 				}
 
 				// select/deselect single wire
-				activeWire = activeNet->containsWire(e->pos());
-				if (activeWire) {
-					if (activeSelection->contains(activeWire)) activeSelection->remove(activeWire);
-					else activeSelection->add(activeWire);
-					activeDev = (XDevice *)NULL;
-					activeWire = (XWire *)NULL;
+				m_poActiveWire = m_poActiveCircuit->containsWire(e->pos());
+				if (m_poActiveWire) {
+					if (m_poActiveSelection->contains(m_poActiveWire)) m_poActiveSelection->remove(m_poActiveWire);
+					else m_poActiveSelection->add(m_poActiveWire);
+					m_poActiveDevice = (XDevice *)NULL;
+					m_poActiveWire = (XWire *)NULL;
 					p.begin(this);
-					activeSelection->erase(&p);
-					activeNet->drawAll(this, &p);
-					activeSelection->draw(&p);
+					m_poActiveSelection->erase(&p);
+					m_poActiveCircuit->draw(this, &p);
+					m_poActiveSelection->draw(&p);
 					p.end();
 					return;
 				}
 
 				// group selections
 				p.begin(this);
-				activeSelection->erase(&p);
+				m_poActiveSelection->erase(&p);
 				p.end();
-				activeSelection->beginFrame(e->pos());
+				m_poActiveSelection->beginFrame(e->pos());
 			}
 			p.begin(this);
-			activeSelection->erase(&p);
-			activeNet->drawAll(this, &p);
-			activeSelection->draw(&p);
+			m_poActiveSelection->erase(&p);
+			m_poActiveCircuit->draw(this, &p);
+			m_poActiveSelection->draw(&p);
 			p.end();
 			return;
 		}
@@ -378,14 +378,14 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 	if (e->button() == RightButton) {
 		// right clicked in selection mode? open popup to choose operation
 		if (MainWidget::getMode() == MainWidget::MAIN_MODE_SELECT) {
-			activeSelection->at(e->pos());
+			m_poActiveSelection->at(e->pos());
 			selRightSelMenu(e);
 			m_bRMenuActive = true;
 			return;
 		}
 
 		// device right clicked? open popup to chooce operation
-		if (NULL != (activeDev = activeNet->containsDev(e->pos()))) {
+		if (NULL != (m_poActiveDevice = m_poActiveCircuit->containsDev(e->pos()))) {
 			selRightMenu(e);
 			m_bRMenuActive = true;
 			return;
@@ -399,9 +399,9 @@ void NetWidget::mousePressEvent( QMouseEvent *e )
 
 		// wire right clicked? remove node 
 		p.begin(this);
-		if (activeNet->removeNode(&p, e->pos())) {
-			activeNet->drawAll(this, &p);
-			activeWire = (XWire *)NULL;
+		if (m_poActiveCircuit->removeNode(&p, e->pos())) {
+			m_poActiveCircuit->draw(this, &p);
+			m_poActiveWire = (XWire *)NULL;
 			emit netContentChanged();
 			changed = true;
 			p.end();
@@ -418,35 +418,35 @@ void NetWidget::mouseReleaseEvent( QMouseEvent *e)
 	if (e->button() == RightButton) return;
 
 	if (MainWidget::getMode() == MainWidget::MAIN_MODE_SELECT) {
-		if (activeSelection->getStatus() == SEL_START) {	// making frames
-			activeSelection->endFrame();
+		if (m_poActiveSelection->getStatus() == SEL_START) {	// making frames
+			m_poActiveSelection->endFrame();
 			return;
 		}
-		if (activeSelection->getStatus() == SEL_MOVE) {	// moving frames or select devices
-			activeSelection->endMove();
+		if (m_poActiveSelection->getStatus() == SEL_MOVE) {	// moving frames or select devices
+			m_poActiveSelection->endMove();
 
-			if (! activeSelection->hasMoved()) {
+			if (! m_poActiveSelection->hasMoved()) {
 				// select/deselect single device when group was not moved
-				activeDev = activeNet->containsDev(e->pos());
-				if (activeDev) {
-					if (activeSelection->isTemp(activeDev)) activeSelection->fixTemp(activeDev);
-					else activeSelection->remove(activeDev);
-					activeDev = (XDevice *)NULL;
-					activeWire = (XWire *)NULL;
+				m_poActiveDevice = m_poActiveCircuit->containsDev(e->pos());
+				if (m_poActiveDevice) {
+					if (m_poActiveSelection->isTemp(m_poActiveDevice)) m_poActiveSelection->fixTemp(m_poActiveDevice);
+					else m_poActiveSelection->remove(m_poActiveDevice);
+					m_poActiveDevice = (XDevice *)NULL;
+					m_poActiveWire = (XWire *)NULL;
 					p.begin(this);
-					activeSelection->erase(&p);
-					activeNet->drawAll(this, &p);
-					activeSelection->draw(&p);
+					m_poActiveSelection->erase(&p);
+					m_poActiveCircuit->draw(this, &p);
+					m_poActiveSelection->draw(&p);
 					p.end();
-					activeDev = (XDevice *)NULL;
+					m_poActiveDevice = (XDevice *)NULL;
 					return;
 				}
 			}
-			activeDev = activeNet->containsDev(e->pos());
-			if (activeDev) {
+			m_poActiveDevice = m_poActiveCircuit->containsDev(e->pos());
+			if (m_poActiveDevice) {
 				// look if some wires want to drop nodes..
-				activeDev->garbageCollection();
-				activeDev = (XDevice *)NULL;
+				m_poActiveDevice->garbageCollection();
+				m_poActiveDevice = (XDevice *)NULL;
 			}
 			return;
 		}
@@ -454,33 +454,33 @@ void NetWidget::mouseReleaseEvent( QMouseEvent *e)
 	}
 
 	// check for collision with another device
-	if (activeDev) {
+	if (m_poActiveDevice) {
 		//look for devices lying in the device 
-		if (activeNet->containsDev(activeDev)) {
-			activeDev->toOrigin();
+		if (m_poActiveCircuit->containsDev(m_poActiveDevice)) {
+			m_poActiveDevice->toOrigin();
 			p.begin(this);
-			activeNet->drawDev(this, &p, activeDev);
+			m_poActiveCircuit->drawDev(this, &p, m_poActiveDevice);
 			p.end();
 		}
 
 		// if device was not moved and it is interactive, toggle its status
-		if (activeDev->isInteractive() && activeDev->isOrigin(e->pos())) {
-			activeDev->toggleStaticInput();
+		if (m_poActiveDevice->isInteractive() && m_poActiveDevice->isOrigin(e->pos())) {
+			m_poActiveDevice->toggleStaticInput();
 			p.begin(this);
-			activeNet->drawAll(this, &p);
+			m_poActiveCircuit->draw(this, &p);
 			p.end();
 		}
 
 		// look if some wires want to drop nodes..
-		activeDev->garbageCollection();
-		activeDev = (XDevice *)NULL;
+		m_poActiveDevice->garbageCollection();
+		m_poActiveDevice = (XDevice *)NULL;
 
 		emit netContentChanged();
 		changed = true;
 	}
-	if (activeWire) {
+	if (m_poActiveWire) {
 		// check for connection to device or another wire
-		ret = activeNet->checkConnection(activeWire);
+		ret = m_poActiveCircuit->checkConnection(m_poActiveWire);
 		switch (ret) {
 		case NFAIL:
 			QMessageBox::warning(m_oParent,
@@ -506,10 +506,10 @@ void NetWidget::mouseReleaseEvent( QMouseEvent *e)
 			break;
 		}
 		p.begin(this);
-		activeWire->erase(&p);
-		activeNet->releaseWire(&p, activeWire);
-		activeWire = (XWire *)NULL;
-		activeNet->drawAll(this, &p);
+		m_poActiveWire->erase(&p);
+		m_poActiveCircuit->releaseWire(&p, m_poActiveWire);
+		m_poActiveWire = (XWire *)NULL;
+		m_poActiveCircuit->draw(this, &p);
 		p.end();
 		emit netContentChanged();
 		changed = true;
@@ -522,7 +522,7 @@ void NetWidget::mouseMoveEvent( QMouseEvent *e )
 	if (MainWidget::getMode() == MainWidget::MAIN_MODE_SELECT) {
 		if (!hasMouseTracking())
 			setMouseTracking(true);
-		if (activeSelection->getStatus() == SEL_EXISTS && activeSelection->onFrame(e->pos())) {
+		if (m_poActiveSelection->getStatus() == SEL_EXISTS && m_poActiveSelection->onFrame(e->pos())) {
 			if (!m_bSelMoveCursor) {
 				m_bSelMoveCursor = true;
 				setCursor(sizeAllCursor);
@@ -534,22 +534,22 @@ void NetWidget::mouseMoveEvent( QMouseEvent *e )
 				setCursor(arrowCursor);
 				return;
 			}
-			if (activeSelection->getStatus() == SEL_START) {	// make selections
+			if (m_poActiveSelection->getStatus() == SEL_START) {	// make selections
 				emit(autoMove(e->pos()));	// move circuit when nessecary
-				activeSelection->changeFrame(e->pos());
+				m_poActiveSelection->changeFrame(e->pos());
 				p.begin(this);
-				activeSelection->erase(&p);
-				activeNet->drawAll(this, &p);
-				activeSelection->draw(&p);
+				m_poActiveSelection->erase(&p);
+				m_poActiveCircuit->draw(this, &p);
+				m_poActiveSelection->draw(&p);
 				p.end();
 				emit netContentChanged();
 				return;
 			}
-			if (activeSelection->getStatus() == SEL_MOVE) {		// move selections
+			if (m_poActiveSelection->getStatus() == SEL_MOVE) {		// move selections
 				emit(autoMove(e->pos()));	// move circuit when nessecary
 				p.begin(this);
-				activeSelection->moveFrame(e->pos(), &p);
-				activeNet->drawAll(this, &p);
+				m_poActiveSelection->moveFrame(e->pos(), &p);
+				m_poActiveCircuit->draw(this, &p);
 				p.end();
 				emit netContentChanged();
 				return;
@@ -559,8 +559,8 @@ void NetWidget::mouseMoveEvent( QMouseEvent *e )
 	}
 
 	if (hasMouseTracking()) {
-		activeDev = (XDevice *)NULL;
-		activeWire = (XWire *)NULL;
+		m_poActiveDevice = (XDevice *)NULL;
+		m_poActiveWire = (XWire *)NULL;
 		m_bSelMoveCursor = false;
 		setCursor(arrowCursor);
 		setMouseTracking(false);
@@ -569,23 +569,23 @@ void NetWidget::mouseMoveEvent( QMouseEvent *e )
 	if (m_bRMenuActive) return;
 
 	// move wire/device
-	if (activeDev) {
+	if (m_poActiveDevice) {
 		emit(autoMove(e->pos()));	// move circuit when nessecary
 
-		if (activeDev->setPos(e->pos())) {
+		if (m_poActiveDevice->moveTo(e->pos())) {
 			p.begin(this);
-			activeNet->drawDev(this, &p, activeDev);
+			m_poActiveCircuit->drawDev(this, &p, m_poActiveDevice);
 			p.end();
 			emit netContentChanged();
 		}
 	}
-	if (activeWire) {
+	if (m_poActiveWire) {
 		emit(autoMove(e->pos()));	// move if nessecary
 
 		p.begin(this);
-		activeWire->erase(&p);
-		activeWire->updateNode(e->pos());
-		activeNet->drawAll(this, &p);
+		m_poActiveWire->erase(&p);
+		m_poActiveWire->updateNode(e->pos());
+		m_poActiveCircuit->draw(this, &p);
 		p.end();
 		emit netContentChanged();
 	}
@@ -594,10 +594,10 @@ void NetWidget::mouseMoveEvent( QMouseEvent *e )
 void NetWidget::mouseDoubleClickEvent( QMouseEvent *e )
 {
 	// device clicked?
-	activeDev = activeNet->containsDev(e->pos());
-	if (activeDev) {
-		if (activeDev->type() == DeviceType::fSWI) {
-			activeDev = (XDevice *)NULL;
+	m_poActiveDevice = m_poActiveCircuit->containsDev(e->pos());
+	if (m_poActiveDevice) {
+		if (m_poActiveDevice->type() == DeviceType::fSWI) {
+			m_poActiveDevice = (XDevice *)NULL;
 			return;
 		}
 
@@ -633,14 +633,14 @@ void NetWidget::paintEvent(QPaintEvent *)
 	for(x = x1s ; x < x2s ;x += Grid::GRID)
 		for(y = y1s; y < y2s; y += Grid::GRID)
 			p.drawPoint(x, y);
-	activeNet->drawAll(this, &p);
-	activeSelection->draw(&p);
+	m_poActiveCircuit->draw(this, &p);
+	m_poActiveSelection->draw(&p);
 	p.end();
 }
 
 int NetWidget::printNet(QPainter *p)
 {
-	activeNet->drawAll((QPaintDevice *)NULL, p);
+	m_poActiveCircuit->draw((QPaintDevice *)NULL, p);
 	return 1;
 }
 
@@ -648,26 +648,26 @@ int NetWidget::printNet(QPainter *p)
 // menu depends on device type
 void NetWidget::selRightMenu(QMouseEvent *e)
 {
-	if (!activeDev) return;
+	if (!m_poActiveDevice) return;
 
 	rpop->clear();
 	rpop->insertItem(i18n("properties"), RPOP_PROP);
-	if (activeDev->type() == DeviceType::fNET) {
+	if (m_poActiveDevice->type() == DeviceType::fNET) {
 		rpop->insertItem(i18n("open"), RPOP_SUB);
 		rpop->insertItem(i18n("open in window"), RPOP_SUBW);
 		rpop->insertItem(i18n("display graph"), RPOP_SHOWGRAPH);
 	}
-	if (activeDev->type() == DeviceType::fEQU) {
+	if (m_poActiveDevice->type() == DeviceType::fEQU) {
 		rpop->insertItem(i18n("equations"), RPOP_EQU);
 	}
-	if (activeDev->drawGraph()) {
-		if (activeDev->graphEnabled()) {
+	if (m_poActiveDevice->drawGraph()) {
+		if (m_poActiveDevice->graphEnabled()) {
 			rpop->insertItem(i18n("hide graph"), RPOP_GRAPH);
 		} else {
 			rpop->insertItem(i18n("show graph"), RPOP_GRAPH);
 		}
 	}
-	if (activeDev->type() == DeviceType::fEQU || activeDev->type() == DeviceType::fNET) {
+	if (m_poActiveDevice->type() == DeviceType::fEQU || m_poActiveDevice->type() == DeviceType::fNET) {
 		rpop->insertItem(i18n("add to lib"), RPOP_ADD_LIB);
 	}
 
@@ -697,19 +697,19 @@ void NetWidget::rmenuCallback(int val)
 			toSubNetW();	// to sub circuit, new window
 			break;
 		case RPOP_GRAPH:
-			if (!activeDev) return;
-			if (activeDev->graphEnabled()) activeDev->enableGraph(0);
-			else activeDev->enableGraph(1);
+			if (!m_poActiveDevice) return;
+			if (m_poActiveDevice->graphEnabled()) m_poActiveDevice->enableGraph(0);
+			else m_poActiveDevice->enableGraph(1);
 			emit graphChanged();
 			break;
 		case RPOP_SHOWGRAPH:
-			if (activeDev->devIsCircuit())
-				emit showGraph(activeDev->devIsCircuit());
+			if (m_poActiveDevice->devIsCircuit())
+				emit showGraph(m_poActiveDevice->devIsCircuit());
 			break;
 		case RPOP_ADD_LIB:
 			// send signal to main widget
-			if (activeDev)
-				emit addToLib(activeDev);
+			if (m_poActiveDevice)
+				emit addToLib(m_poActiveDevice);
 			break;
 		default:
 			break;
@@ -731,25 +731,25 @@ void NetWidget::rmenuSelCallback(int val)
 	switch(val) {
 		case RPOPSEL_CUT:
 			p.begin(this);
-			activeSelection->cut(&p, activeNet);
-			activeNet->drawAll(this, &p);
+			m_poActiveSelection->cut(&p, m_poActiveCircuit);
+			m_poActiveCircuit->draw(this, &p);
 			p.end();
 			emit netContentChanged();
 			emit graphChanged();
 			changed = true;
 			break;
 		case RPOPSEL_COPY:
-			activeSelection->copy(activeNet);
+			m_poActiveSelection->copy(m_poActiveCircuit);
 			break;
 		case RPOPSEL_PASTE:
-			activeSelection->at(QPoint(40, 10));
+			m_poActiveSelection->at(QPoint(40, 10));
 		case RPOPSEL_PASTEAT:
 			p.begin(this);
-			activeSelection->paste(&p, activeNet);
-			activeSelection->erase(&p);
-			activeNet->drawStatus(this, &p);
-			activeNet->drawAll(this, &p);
-			activeSelection->draw(&p);
+			m_poActiveSelection->paste(&p, m_poActiveCircuit);
+			m_poActiveSelection->erase(&p);
+			m_poActiveCircuit->drawStatus(this, &p);
+			m_poActiveCircuit->draw(this, &p);
+			m_poActiveSelection->draw(&p);
 			p.end();
 			emit netContentChanged();
 			emit graphChanged();
@@ -766,10 +766,10 @@ void NetWidget::removeSelection()
 {	QPainter p;
 
 	p.begin(this);
-	activeSelection->remove(&p, 1);
-	activeSelection->erase(&p);
-	activeNet->drawAll(this, &p);
-	activeSelection->draw(&p);
+	m_poActiveSelection->remove(&p, 1);
+	m_poActiveSelection->erase(&p);
+	m_poActiveCircuit->draw(this, &p);
+	m_poActiveSelection->draw(&p);
 	p.end();
 }
 
@@ -778,26 +778,26 @@ void NetWidget::deleteDev(int ask)
 {	QPainter p;
 	int simw_rel = 1;
 
-	if (activeDev->type() == DeviceType::fNET) {
+	if (m_poActiveDevice->type() == DeviceType::fNET) {
 		if (ask) {
 			if (1 == QMessageBox::warning(m_oParent, i18n("remove device"),
 					i18n("remove entire sub-circuit?"), i18n("OK"), i18n("Cancel")))
 			{
-				activeDev = (XDevice *)NULL;
+				m_poActiveDevice = (XDevice *)NULL;
 				return;
 			}
 		}
 		emit netContentChanged();
-		emit netDeleted(activeDev->devIsCircuit());
+		emit netDeleted(m_poActiveDevice->devIsCircuit());
 	}
-	if (!activeDev->drawGraph() ||  !activeDev->graphEnabled())
+	if (!m_poActiveDevice->drawGraph() ||  !m_poActiveDevice->graphEnabled())
 		simw_rel = 0;
 
 	p.begin(this);
-	activeNet->deleteDevice(&p, activeDev);
-	activeNet->drawAll(this, &p);
+	m_poActiveCircuit->deleteDevice(&p, m_poActiveDevice);
+	m_poActiveCircuit->draw(this, &p);
 	p.end();
-	activeDev = (XDevice *)NULL;
+	m_poActiveDevice = (XDevice *)NULL;
 
 	if (simw_rel) emit graphChanged();
 }
@@ -807,13 +807,13 @@ int NetWidget::openProp()
 {	QPainter p;
 
 	// open properties for oszillators
-	if (activeDev->type() == DeviceType::fOSC) {
-		PropOsz *dlg = new PropOsz(m_oParent, i18n("oscillator properties"), activeNet, activeDev);
+	if (m_poActiveDevice->type() == DeviceType::fOSC) {
+		PropOsz *dlg = new PropOsz(m_oParent, i18n("oscillator properties"), m_poActiveCircuit, m_poActiveDevice);
 		if (simmode == MODE_SIM_MULT) simTimer.stop();
 		dlg->exec();
 		if (simmode == MODE_SIM_MULT) simTimer.start(STATsimStepTime);
 		delete dlg;
-		activeDev = (XDevice *)NULL;
+		m_poActiveDevice = (XDevice *)NULL;
 		emit netContentChanged();
 		changed = true;
 		emit graphChanged();
@@ -821,25 +821,25 @@ int NetWidget::openProp()
 	}
 
 	// open properties for text devices
-	if (activeDev->type() == DeviceType::fTXT) {
-		PropText *dlg = new PropText(m_oParent, i18n("text label"), activeNet, activeDev);
+	if (m_poActiveDevice->type() == DeviceType::fTXT) {
+		PropText *dlg = new PropText(m_oParent, i18n("text label"), m_poActiveCircuit, m_poActiveDevice);
 		dlg->exec();
 		delete dlg;
-		activeDev = (XDevice *)NULL;
+		m_poActiveDevice = (XDevice *)NULL;
 		emit netContentChanged();
 		changed = true;
 		return 1;
 	}
 
 	// open properties for power sources
-	if (activeDev->type() == DeviceType::fPWR) {
-		PropPwr *dlg = new PropPwr(m_oParent, i18n("power device properties"), activeNet, activeDev);
+	if (m_poActiveDevice->type() == DeviceType::fPWR) {
+		PropPwr *dlg = new PropPwr(m_oParent, i18n("power device properties"), m_poActiveCircuit, m_poActiveDevice);
 		dlg->exec();
 		delete dlg;
 		p.begin(this);
-		activeNet->drawStatus(this, &p);
+		m_poActiveCircuit->drawStatus(this, &p);
 		p.end();
-		activeDev = (XDevice *)NULL;
+		m_poActiveDevice = (XDevice *)NULL;
 		emit netContentChanged();
 		changed = true;
 		emit graphChanged();
@@ -847,14 +847,14 @@ int NetWidget::openProp()
 	}
 
 	// open properties for switch devices
-	if (activeDev->type() == DeviceType::fSWI) {
-		PropSwitch *dlg = new PropSwitch(m_oParent, i18n("switch device properties"), activeNet, activeDev);
+	if (m_poActiveDevice->type() == DeviceType::fSWI) {
+		PropSwitch *dlg = new PropSwitch(m_oParent, i18n("switch device properties"), m_poActiveCircuit, m_poActiveDevice);
 		if (simmode == MODE_SIM_MULT) simTimer.stop();
 		dlg->exec();
 		if (simmode == MODE_SIM_MULT) simTimer.start(STATsimStepTime);
 		
 		delete dlg;
-		activeDev = (XDevice *)NULL;
+		m_poActiveDevice = (XDevice *)NULL;
 		emit netContentChanged();
 		changed = true;
 		emit graphChanged();
@@ -862,15 +862,15 @@ int NetWidget::openProp()
 	}
 
 	// open properties for inputs and ouputs
-	if ((activeDev->type() == DeviceType::fIN) ||
-	    (activeDev->type() == DeviceType::fOUT)) {
-		PropName *dlg = new PropName(m_oParent, i18n("interface device name"), this, activeNet, activeDev);
+	if ((m_poActiveDevice->type() == DeviceType::fIN) ||
+	    (m_poActiveDevice->type() == DeviceType::fOUT)) {
+		PropName *dlg = new PropName(m_oParent, i18n("interface device name"), this, m_poActiveCircuit, m_poActiveDevice);
 		if (simmode == MODE_SIM_MULT) simTimer.stop();
 		dlg->exec();
 		if (simmode == MODE_SIM_MULT) simTimer.start(STATsimStepTime);
 		
 		delete dlg;
-		activeDev = (XDevice *)NULL;
+		m_poActiveDevice = (XDevice *)NULL;
 		emit netContentChanged();
 		changed = true;
 		emit graphChanged();
@@ -878,14 +878,14 @@ int NetWidget::openProp()
 	}
 
 	// open dialog with common device properties
-	PropDev *dlg = new PropDev(m_oParent, i18n("device properties"),this ,activeNet, activeDev);
+	PropDev *dlg = new PropDev(m_oParent, i18n("device properties"),this ,m_poActiveCircuit, m_poActiveDevice);
 	if (simmode == MODE_SIM_MULT) simTimer.stop();
 	dlg->exec();
-	activeDev->forceOutputChange();
+	m_poActiveDevice->forceOutputChange();
 	if (simmode == MODE_SIM_MULT) simTimer.start(STATsimStepTime);
 
 	delete dlg;
-	activeDev = (XDevice *)NULL;
+	m_poActiveDevice = (XDevice *)NULL;
 	emit netContentChanged();
 	changed = true;
 	emit graphChanged();
@@ -894,16 +894,16 @@ int NetWidget::openProp()
 
 // switch to sub circuit in a new window?
 int NetWidget::toSubNetW()
-{	Circuit *new_activeNet;
+{	Circuit *new_m_poActiveCircuit;
 
-	if (!activeDev) return 0;
+	if (!m_poActiveDevice) return 0;
 
-	new_activeNet = activeDev->devIsCircuit();
-	if (new_activeNet) {
+	new_m_poActiveCircuit = m_poActiveDevice->devIsCircuit();
+	if (new_m_poActiveCircuit) {
 		// remove the current selection before switching to a new circuit
 		removeSelection();
-		new_activeNet->forceOutputChange();
-		emit createNewWidget(new_activeNet);	// signal goes to main widget (mainw.cpp)
+		new_m_poActiveCircuit->forceOutputChange();
+		emit createNewWidget(new_m_poActiveCircuit);	// signal goes to main widget (mainw.cpp)
 		return 1;
 	}
 	return 0;
@@ -911,22 +911,22 @@ int NetWidget::toSubNetW()
 
 // switch to sub circuit?
 int NetWidget::toSubNet()
-{	Circuit *new_activeNet;
+{	Circuit *new_m_poActiveCircuit;
 
-	new_activeNet = activeDev->devIsCircuit();
-	if (new_activeNet) {
+	new_m_poActiveCircuit = m_poActiveDevice->devIsCircuit();
+	if (new_m_poActiveCircuit) {
 		// remove the current selection before switching to a new circuit
 		removeSelection();
 
-		activeNet = new_activeNet;
-		activeDev = (XDevice *)NULL;
-		activeWire = (XWire *)NULL;
+		m_poActiveCircuit = new_m_poActiveCircuit;
+		m_poActiveDevice = (XDevice *)NULL;
+		m_poActiveWire = (XWire *)NULL;
 		// signal mainw info about parent or not (changes toolbar)
-		if (activeNet->parent())
+		if (m_poActiveCircuit->parent())
 			emit netChanged(1);
 		else
 			emit netChanged(0);
-		activeNet->forceOutputChange();
+		m_poActiveCircuit->forceOutputChange();
 		repaint(TRUE);
 		return 1;
 	}
@@ -935,33 +935,33 @@ int NetWidget::toSubNet()
 
 // switch to parent of active net
 void NetWidget::toParentNet()
-{	Circuit *new_activeNet;
+{	Circuit *new_m_poActiveCircuit;
 
 	// remove the current selection before switching to a new circuit
 	removeSelection();
 
-	new_activeNet = activeNet->parent();
-	if (!new_activeNet) {
+	new_m_poActiveCircuit = m_poActiveCircuit->parent();
+	if (!new_m_poActiveCircuit) {
 		warning("no parent net!?");
 		return;
 	}
-	activeNet = new_activeNet;
-	activeWire = (XWire *)NULL;
-	activeDev = (XDevice *)NULL;
+	m_poActiveCircuit = new_m_poActiveCircuit;
+	m_poActiveWire = (XWire *)NULL;
+	m_poActiveDevice = (XDevice *)NULL;
 	repaint(TRUE);
 	// signal mainw info about having a parent (changes toolbar)
-	if (activeNet->parent())
+	if (m_poActiveCircuit->parent())
 		emit netChanged(1);
 	else
 		emit netChanged(0);
-	activeNet->forceOutputChange();
+	m_poActiveCircuit->forceOutputChange();
 }
 
 bool NetWidget::saveAsSubNet()
-{	Circuit *_net = activeNet->rootParent();
+{	Circuit *_net = m_poActiveCircuit->rootParent();
 
-	_net = activeNet->rootParent();
-	if (_net != activeNet) {	
+	_net = m_poActiveCircuit->rootParent();
+	if (_net != m_poActiveCircuit) {	
 		int ret = QMessageBox::warning(m_oParent,
 				i18n("save circuit"),
 				i18n("the current circuit is a sub circuit.\nsave it as a.."),
@@ -977,9 +977,9 @@ int NetWidget::saveNet(QString filename, bool as_sub_net)
 	int ret;
 
 	if (as_sub_net)
-		net = activeNet;
+		net = m_poActiveCircuit;
 	else
-		net = activeNet->rootParent();
+		net = m_poActiveCircuit->rootParent();
 
 	emit netContentUnchanged();
 	changed = false;
@@ -1023,13 +1023,13 @@ int NetWidget::openNet(QString filename, bool main_circuit_changed)
 		// is a sub circuit
 		// -----------------------------------------
 		create_sub = true;
-		_net = activeNet;
+		_net = m_poActiveCircuit;
 	} else if (file_type == klogicIO::XML_MAIN || file_type == klogicIO::KLOGIC_MAIN) {
 		//fprintf(stderr, "MAIN import\n");
 		// -----------------------------------------
 		// replace main circuit: ask!
 		// -----------------------------------------
-		if (main_circuit_changed && !activeNet->rootParent()->empty()) {
+		if (main_circuit_changed && !m_poActiveCircuit->rootParent()->empty()) {
 			if (QMessageBox::Yes != QMessageBox::warning(m_oParent,
 				i18n("new circuit"), 
 				i18n("delete current circuit?"), 
@@ -1037,14 +1037,15 @@ int NetWidget::openNet(QString filename, bool main_circuit_changed)
 				QMessageBox::No))
 				return 1;
 		}
-		_net = activeNet->rootParent();
-		activeNet = _net;
-		activeDev = (XDevice *)NULL;
-		activeWire = (XWire *)NULL;
+		_net = m_poActiveCircuit->rootParent();
+		m_poActiveCircuit = _net;
+		m_poActiveDevice = (XDevice *)NULL;
+		m_poActiveWire = (XWire *)NULL;
 
 		p.begin(this);
-		activeNet->deleteCircuit(&p);
+		m_poActiveCircuit->erase(&p);
 		p.end();
+		m_poActiveCircuit->deleteAll();
 		emit netContentUnchanged();
 		uniqueID::reset();
 		changed = false;
@@ -1092,10 +1093,10 @@ int NetWidget::openNet(QString filename, bool main_circuit_changed)
 		p.begin(this);
 /*
 		// remove useless nodes/wires
-		activeNet->garbageCollection(&p);
+		m_poActiveCircuit->garbageCollection(&p);
 */
 		// redraw everything
-		activeNet->drawStatus(this, &p);
+		m_poActiveCircuit->drawStatus(this, &p);
 		p.end();
 
 		return 0;
@@ -1107,7 +1108,7 @@ int NetWidget::openNet(QString filename, bool main_circuit_changed)
 	repaint(TRUE);
 
 	// signal mainw info about having a parent or not (changes toolbar)
-	if (activeNet->parent())
+	if (m_poActiveCircuit->parent())
 		emit netChanged(1);
 	else
 		emit netChanged(0);
@@ -1117,9 +1118,9 @@ int NetWidget::openNet(QString filename, bool main_circuit_changed)
 
 	p.begin(this);
 	// remove useless nodes/wires
-	activeNet->garbageCollection(&p);
+	m_poActiveCircuit->garbageCollection(&p);
 	// redraw everything
-	activeNet->drawStatus(this, &p);
+	m_poActiveCircuit->drawStatus(this, &p);
 	p.end();
 
 	if (create_sub) return 2;
@@ -1129,15 +1130,16 @@ int NetWidget::openNet(QString filename, bool main_circuit_changed)
 int NetWidget::newNet()
 {	QPainter p;
 
-	if ((changed && !activeNet->empty() &&
+	if ((changed && !m_poActiveCircuit->empty() &&
 			QMessageBox::Yes == (QMessageBox::warning(m_oParent,
 			i18n("new circuit"), 
 			i18n("delete current circuit?"), 
 			QMessageBox::Yes,
 			QMessageBox::No))) || (!changed)) {
 		p.begin(this);
-		activeNet->deleteCircuit(&p);
+		m_poActiveCircuit->erase(&p);
 		p.end();
+		m_poActiveCircuit->deleteAll();
 		repaint(TRUE);
 		emit netContentUnchanged();
 		changed = false;
@@ -1151,22 +1153,22 @@ int NetWidget::newNet()
 // display dialog with the equations of the current circuit
 void NetWidget::showCircuitEquations()
 {
-	if (!activeNet->checkCircuitNames()) {
+	if (!m_poActiveCircuit->checkCircuitNames()) {
 		if (QMessageBox::No == (QMessageBox::warning(this,
 				i18n("Parse circuit equations"),
 				i18n("There are some non unique device names \nwithin your circuit ... \n\nrename them automaticly?"),
 				QMessageBox::Yes,
 				QMessageBox::No)))
 			return;
-		activeNet->unifyCircuitNames();
+		m_poActiveCircuit->unifyCircuitNames();
 	}
-	if (activeNet->hasImpossibleEquations()) {
+	if (m_poActiveCircuit->hasImpossibleEquations()) {
 		QMessageBox::information(this,
 			i18n("Parse circuit equations"),
 			i18n("Unable to display equations for circuits containing \nRAM or Tristate devices!"));
 		return;
 	} 
-	DlgEqu *equation_dialog = new DlgEqu(this, i18n("Circuit Equation Editor"), activeNet);
+	DlgEqu *equation_dialog = new DlgEqu(this, i18n("Circuit Equation Editor"), m_poActiveCircuit);
 	equation_dialog->exec();
 	delete equation_dialog;
 }
@@ -1174,8 +1176,8 @@ void NetWidget::showCircuitEquations()
 // display dialog with the equations of the active device
 void NetWidget::showDeviceEquations()
 {
-	if (!activeDev) return;
-	DlgEqu * equation_dialog = new DlgEqu(this, i18n("Device Equation Editor"), activeDev);
+	if (!m_poActiveDevice) return;
+	DlgEqu * equation_dialog = new DlgEqu(this, i18n("Device Equation Editor"), m_poActiveDevice);
 	equation_dialog->exec();
 	delete equation_dialog;
 }
@@ -1183,12 +1185,12 @@ void NetWidget::showDeviceEquations()
 // retrieve the active Circuit
 Circuit *NetWidget::getActive()
 {
-	return activeNet;
+	return m_poActiveCircuit;
 }
 
 // check if given net is this or a parent of this
 int NetWidget::contained(Circuit *rootnet)
-{	Circuit *_rootnet = activeNet;
+{	Circuit *_rootnet = m_poActiveCircuit;
 
 	if (_rootnet == rootnet) return 1;
 	while(NULL != (_rootnet = _rootnet->parent())) {
@@ -1205,12 +1207,12 @@ void NetWidget::simStep()
 
 	if (!client) {
 		// process a simulation step
-		activeNet->rootParent()->Burst(STATsimBurst);
+		m_poActiveCircuit->rootParent()->Burst(STATsimBurst);
 		emit simStepped();
 	}
 	p.begin(this);
 	// draw wires and devices with changed image
-	ret = activeNet->drawStatus(this, &p);
+	ret = m_poActiveCircuit->drawStatus(this, &p);
 	p.end();
 
 	// runtime shortcut occured?
@@ -1241,7 +1243,7 @@ void NetWidget::visible(const QRect& newvisi)
 
 // apply device defaults to all existing devices
 void NetWidget::applyDefaults()
-{	Circuit *toplevel = activeNet->rootParent();
+{	Circuit *toplevel = m_poActiveCircuit->rootParent();
 
 	toplevel->applyDefaults();
 	repaint(TRUE);
