@@ -25,6 +25,7 @@
 #include "inverterw.h"
 #include "ramw.h"
 #include "dlgEqu.h"
+#include "deviceColored.h"
 #include "deviceTypes.h"
 
 #include "propDev.h"
@@ -62,7 +63,7 @@ PropDev::PropDev(QWidget *parent, const char *name, NetWidget *_netw, Circuit *_
 	delay->setValidator(vDelay);
 	delay->setGeometry(80, 40, 40, 20);
 	delay->setMaxLength(4);
-	delay->setText(value.setNum(dev->delay()));
+	delay->setText(value.setNum(dev->getDelay()));
     }
 
     if (dev->type() == DeviceType::fBUS) {
@@ -121,7 +122,7 @@ PropDev::PropDev(QWidget *parent, const char *name, NetWidget *_netw, Circuit *_
 	undef[0]->setGeometry(30, 16, 100, 20);
 	undef[1] = new QRadioButton(i18n("High"), bg_undef);
 	undef[1]->setGeometry(30, 36, 100, 20);
-	if (dev->undef()) {
+	if (dev->getUndefinedValue()) {
 		undef[1]->setChecked(TRUE);
 		curr_undef = 1;
 	} else {
@@ -130,13 +131,10 @@ PropDev::PropDev(QWidget *parent, const char *name, NetWidget *_netw, Circuit *_
 	}
 	bg_undef->insert(undef[0], 0);
 	bg_undef->insert(undef[1], 1);
-	connect(bg_undef, SIGNAL(clicked(int)), this, SLOT(setUndefined(int)));
+	connect(bg_undef, SIGNAL(clicked(int)), this, SLOT(setUndefinedValue(int)));
     }
 
-    if (dev->type() == DeviceType::fLEDred ||
-	dev->type() == DeviceType::fLEDblue ||
-	dev->type() == DeviceType::fLEDgreen ||
-	dev->type() == DeviceType::fLEDyellow) {
+    if (dev->type() == DeviceType::fLED) {
 	bg_invert = (QButtonGroup *)NULL;
 	invert[0] = (QRadioButton *)NULL;
 	invert[1] = (QRadioButton *)NULL;
@@ -154,17 +152,17 @@ PropDev::PropDev(QWidget *parent, const char *name, NetWidget *_netw, Circuit *_
 	led_green->setGeometry(30, 56, 100, 20);
 	led_yellow = new QRadioButton(i18n("yellow"), bg_led);
 	led_yellow->setGeometry(30, 76, 100, 20);
-	switch(dev->type()) {
-	case DeviceType::fLEDred:
+	switch(dev->getColor()) {
+	case LedDevice::RED:
 		led_red->setChecked(TRUE);
 		break;
-	case DeviceType::fLEDblue:
+	case LedDevice::BLUE:
 		led_blue->setChecked(TRUE);
 		break;
-	case DeviceType::fLEDgreen:
+	case LedDevice::GREEN:
 		led_green->setChecked(TRUE);
 		break;
-	case DeviceType::fLEDyellow:
+	case LedDevice::YELLOW:
 		led_yellow->setChecked(TRUE);
 		break;
 	}
@@ -279,8 +277,8 @@ PropDev::PropDev(QWidget *parent, const char *name, NetWidget *_netw, Circuit *_
 		clock[4] = new QRadioButton(i18n("Disabled"), bg_clock);
 		clock[4]->setGeometry(15,96, 140, 20);
 	}
-	clock[dev->clock()]->setChecked(TRUE);
 	curr_clock = dev->clock();
+	clock[curr_clock]->setChecked(TRUE);
 	bg_clock->insert(clock[5], 5);
 	bg_clock->insert(clock[6], 6);
 	bg_clock->insert(clock[2], 2);
@@ -386,10 +384,6 @@ void PropDev::done(int r)
 		if (delay) {
 			value = delay->text();
 			ivalue = value.toInt();
-			if (ivalue < XDevice::MINDELAY)
-				ivalue = XDevice::MINDELAY;
-			if (ivalue > XDevice::MAXDELAY)
-				ivalue = XDevice::MAXDELAY;
 			dev->setDelay(ivalue);
 		}
 
@@ -401,7 +395,7 @@ void PropDev::done(int r)
 		}
 
 		if (undef) {
-			dev->setUndef(curr_undef);
+			dev->setUndefinedValue(curr_undef);
 			dev->setClock(curr_clock);
 		}
 
@@ -463,28 +457,28 @@ void PropDev::setLEDColor(int color)
 {
 	switch(color) {
 		case 0:
-			dev->changeLEDType(DeviceType::fLEDred);
+			dev->setColor(LedDevice::RED);
 			break;
 		case 1:
-			dev->changeLEDType(DeviceType::fLEDblue);
+			dev->setColor(LedDevice::BLUE);
 			break;
 		case 2:
-			dev->changeLEDType(DeviceType::fLEDgreen);
+			dev->setColor(LedDevice::GREEN);
 			break;
 		case 3:
-			dev->changeLEDType(DeviceType::fLEDyellow);
+			dev->setColor(LedDevice::YELLOW);
 			break;
 	}
 }
 
-void PropDev::setUndefined(int undef)
+void PropDev::setUndefinedValue(int undef)
 {	curr_undef = undef;
 }
 
-void PropDev::setClock(int clk)
+void PropDev::setClock(int iIntClock)
 {
-	curr_clock = clk;
-	dev->setClock(clk);
+	curr_clock = (Global::Device::CLOCKTYPE)iIntClock;
+	dev->setClock(curr_clock);
 	inverterw->setInputButtons();
 	inverterw->repaint(TRUE);
 }
@@ -499,23 +493,23 @@ void PropDev::setMaster(int m)
 		if (clock[0]) clock[0]->setEnabled(TRUE);
 		if (clock[1]) clock[1]->setEnabled(TRUE);
 		clock[4]->setEnabled(FALSE);
-		if (curr_clock == Device::CLK_NONE) {
+		if (curr_clock == Global::Device::CLK_NONE) {
 			clock[6]->setChecked(TRUE);
-			curr_clock = Device::CLK_FALLING_1EDGE;
+			curr_clock = Global::Device::CLK_FALLING_1EDGE;
 			dev->setClock(curr_clock);
 			inverterw->setInputButtons();
 		}
 	} else {
 		clock[5]->setEnabled(FALSE);
-		if (curr_clock == Device::CLK_RISING_1EDGE ||  curr_clock == Device::CLK_RISING_2EDGE) {
+		if (curr_clock == Global::Device::CLK_RISING_1EDGE ||  curr_clock == Global::Device::CLK_RISING_2EDGE) {
 			clock[2]->setChecked(TRUE);
-			curr_clock = Device::CLK_HIGH_VALUE;
+			curr_clock = Global::Device::CLK_HIGH_VALUE;
 			dev->setClock(curr_clock);
 		}
 		clock[6]->setEnabled(FALSE);
-		if (curr_clock == Device::CLK_FALLING_1EDGE || curr_clock == Device::CLK_FALLING_2EDGE) {
+		if (curr_clock == Global::Device::CLK_FALLING_1EDGE || curr_clock == Global::Device::CLK_FALLING_2EDGE) {
 			clock[3]->setChecked(TRUE);
-			curr_clock = Device::CLK_LOW_VALUE;
+			curr_clock = Global::Device::CLK_LOW_VALUE;
 			dev->setClock(curr_clock);
 		}
 		if (clock[0]) clock[0]->setEnabled(FALSE);
@@ -533,10 +527,6 @@ void PropDev::setSize(const QString& value)
 
 void PropDev::setSize(int isize)
 {
-	if (isize < XDevice::MINSIZE)
-		isize = XDevice::MINSIZE;
-	if (isize > XDevice::MAXSIZE)
-		isize = XDevice::MAXSIZE;
 	dev->setSize(isize);
 	dev->setImage();
 	if (inverterw) inverterw->repaint(TRUE);
