@@ -60,10 +60,10 @@ private:
     XDevice *dev;
     int osize;
     int omaster;
-    int oclock;
+    Global::Device::CLOCKTYPE oclock;
     int curr_invert;
     int curr_undef;
-    int curr_clock;
+    Global::Device::CLOCKTYPE curr_clock;
     int curr_mux;
 
     int ram_clr;
@@ -72,7 +72,7 @@ private slots:
     void RAMClrSet();
     void showDeviceEquations();
     void setSize(const QString &);
-    void setUndefined(int);
+    void setUndefinedValue(int);
     void setInverted(int);
     void setClock(int);
     void setMaster(int);
