@@ -47,7 +47,7 @@ PropGlob::PropGlob(MainWidget *_parent, QString name, NetWidget *_netw)
     defsize->setValidator(vDefSize);
     defsize->setGeometry(140, 20, 50, 18);
     defsize->setMaxLength(2);
-    defsize->setText(value.setNum(XDevice::defSize()));
+    defsize->setText(value.setNum(Global::Device::getSize()));
 
     ldelay = new QLabel(gb_dev);
     ldelay->setGeometry(10, 40, 130, 18);
@@ -57,16 +57,16 @@ PropGlob::PropGlob(MainWidget *_parent, QString name, NetWidget *_netw)
     defdelay->setValidator(vDefDelay);
     defdelay->setGeometry(140, 40, 50, 18);
     defdelay->setMaxLength(2);
-    defdelay->setText(value.setNum(Device::defDelay()));
+    defdelay->setText(value.setNum(Global::Device::getDelay()));
 
     cb_display_name = new QCheckBox(i18n("Display Name"), gb_dev);
     cb_display_name->setGeometry(5, 65, 160, 15);
-    if (XDevice::nameDisplayedGlobal()) cb_display_name->setChecked(TRUE);
+    if (Global::Device::isDisplayNames()) cb_display_name->setChecked(TRUE);
     else cb_display_name->setChecked(FALSE);
 
     cb_ext_width = new QCheckBox(i18n("Large Sub Circuit Width"), gb_dev);
     cb_ext_width->setGeometry(5, 85, 180, 15);
-    if (XDevice::defWidth() == 3) cb_ext_width->setChecked(TRUE);
+    if (Global::Device::getWidth() == 3) cb_ext_width->setChecked(TRUE);
     else cb_ext_width->setChecked(FALSE);
 
     bg_invert = new QButtonGroup(i18n("Outputs Inverted"), gb_dev);
@@ -75,7 +75,7 @@ PropGlob::PropGlob(MainWidget *_parent, QString name, NetWidget *_netw)
     invert[0]->setGeometry(10, 20, 160, 15);
     invert[1] = new QRadioButton(i18n("Inverted"), bg_invert);
     invert[1]->setGeometry(10, 40, 160, 15);
-    curr_invert = XDevice::isDefInverted();
+    curr_invert = Global::Device::isInverted();
     if (curr_invert)
         invert[1]->setChecked(TRUE);
     else
@@ -89,7 +89,7 @@ PropGlob::PropGlob(MainWidget *_parent, QString name, NetWidget *_netw)
     undef[0]->setGeometry(10, 20, 160, 15);
     undef[1] = new QRadioButton(i18n("High"), bg_undef);
     undef[1]->setGeometry(10, 40, 160, 15);
-    curr_undef = Device::defUndefined();
+    curr_undef = Global::Device::getUndefinedValue();
     if (curr_undef)
         undef[1]->setChecked(TRUE);
     else
@@ -115,7 +115,7 @@ PropGlob::PropGlob(MainWidget *_parent, QString name, NetWidget *_netw)
     QFontDatabase fntdb;
     QStringList fnt_families = fntdb.families();
     QValueList<int> sizes;
-    QString current_font = XDevice::getFont();
+    QString current_font = Global::Device::getFontFamily();
     int idx = 0;
     int idx2 = 0;
     int current_idx = -1;
@@ -147,7 +147,7 @@ PropGlob::PropGlob(MainWidget *_parent, QString name, NetWidget *_netw)
 			idx2 = 0;
 			for(unsigned int k = 0; k < sizes.count(); k++) {
 				if (sizes[k] <= 10) {
-					if (sizes[k] == XDevice::getFontSize())
+					if (sizes[k] == Global::Device::getFontSize())
 						current_idx_sz = idx2;
 					buf.sprintf("%d", sizes[k]);
 					cb_font_size->insertItem(buf, idx2++);
@@ -169,7 +169,7 @@ PropGlob::PropGlob(MainWidget *_parent, QString name, NetWidget *_netw)
     dev_symbol[0]->setGeometry(10, 20, 160, 15);
     dev_symbol[1] = new QRadioButton(i18n("IEC 617"), bg_dev_symbols);
     dev_symbol[1]->setGeometry(10, 40, 160, 15);
-    if (XDevice::getSymbolSet() == XDevice::SYMBOLSET_DIN40900)
+    if (Global::Device::getSymbolSet() == Global::Device::SYMBOLSET_DIN40900)
 	dev_symbol[0]->setChecked(TRUE);
     else
 	dev_symbol[1]->setChecked(TRUE);
@@ -188,12 +188,8 @@ PropGlob::PropGlob(MainWidget *_parent, QString name, NetWidget *_netw)
     clock[2]->setGeometry(10,60, 180, 15);
     clock[3] = new QRadioButton(i18n("Low value"), bg_clock);
     clock[3]->setGeometry(10,80, 180, 15);
-    curr_clk = Device::defClock();
+    curr_clk = Global::Device::getClock();
     clock[curr_clk]->setChecked(TRUE);
-    invert_trigger = new QCheckBox(i18n("reverse trigger"), bg_clock);
-    invert_trigger->setGeometry(10,110, 180, 15);
-    if (Device::triggerInverted()) invert_trigger->setChecked(TRUE);
-    else invert_trigger->setChecked(FALSE);
     bg_clock->insert(clock[5], 5);
     bg_clock->insert(clock[6], 6);
     bg_clock->insert(clock[2], 2);
@@ -271,31 +267,27 @@ void PropGlob::done(int r)
 
 	if (r == Accepted) {
 		value = defdelay->text();
-		Device::setDefDelay(value.toInt());
-		if (cb_display_name->isChecked()) XDevice::displayNameGlobal(true);
-		else XDevice::displayNameGlobal(false);
-		if (cb_ext_width->isChecked()) XDevice::setDefWidth(3);
-		else XDevice::setDefWidth(2);
+		Global::Device::setDelay(value.toInt());
+		if (cb_display_name->isChecked()) Global::Device::setDisplayNames(true);
+		else Global::Device::setDisplayNames(false);
+		if (cb_ext_width->isChecked()) Global::Device::setWidth(3);
+		else Global::Device::setWidth(2);
 		value = defsize->text();
-		XDevice::setDefSize(value.toInt());
-		Device::setDefUndefined(curr_undef);
-		XDevice::setDefInverted(curr_invert);
-        	Device::setDefClock(curr_clk);
-		XDevice::setFont(cb_font_type->text(cb_font_type->currentItem()));
-		XDevice::setFontSize(cb_font_size->text(cb_font_size->currentItem()).toInt());
-		if (dev_symbol[0]->isChecked() && XDevice::SYMBOLSET_DIN40900 != XDevice::getSymbolSet()) {
-			XDevice::setSymbolSet(XDevice::SYMBOLSET_DIN40900);
+		Global::Device::setSize(value.toInt());
+		Global::Device::setUndefinedValue(curr_undef);
+		Global::Device::setInverted(curr_invert);
+		Global::Device::setClock(curr_clk);
+		Global::Device::setFontFamily(cb_font_type->text(cb_font_type->currentItem()));
+		Global::Device::setFontSize(cb_font_size->text(cb_font_size->currentItem()).toInt());
+		if (dev_symbol[0]->isChecked() && Global::Device::SYMBOLSET_DIN40900 != Global::Device::getSymbolSet()) {
+			Global::Device::setSymbolSet(Global::Device::SYMBOLSET_DIN40900);
 			parent->setToolbarPixmap();
 		}
-		if (dev_symbol[1]->isChecked() && XDevice::SYMBOLSET_IEC617 != XDevice::getSymbolSet()) {
-			XDevice::setSymbolSet(XDevice::SYMBOLSET_IEC617);
+		if (dev_symbol[1]->isChecked() && Global::Device::SYMBOLSET_IEC617 != Global::Device::getSymbolSet()) {
+			Global::Device::setSymbolSet(Global::Device::SYMBOLSET_IEC617);
 			parent->setToolbarPixmap();
 		}
 
-		if (invert_trigger->isChecked())
-			Device::invertTrigger(1);
-		else
-			Device::invertTrigger(0);
 		value = stepTime->text();
 		if (value.toInt() != NetWidget::simTime()) {
 			NetWidget::setSimTime(value.toInt());
@@ -314,31 +306,27 @@ void PropGlob::apply()
 
 	// set new default values
 	value = defdelay->text();
-	Device::setDefDelay(value.toInt());
+	Global::Device::setDelay(value.toInt());
 	value = defsize->text();
-	XDevice::setDefSize(value.toInt());
-	if (cb_display_name->isChecked()) XDevice::displayNameGlobal(true);
-	else XDevice::displayNameGlobal(false);
-	if (cb_ext_width->isChecked()) XDevice::setDefWidth(3);
-	else XDevice::setDefWidth(2);
-	Device::setDefUndefined(curr_undef);
-	XDevice::setDefInverted(curr_invert);
-	Device::setDefClock(curr_clk);
-	XDevice::setFont(cb_font_type->text(cb_font_type->currentItem()));
-	XDevice::setFontSize(cb_font_size->text(cb_font_size->currentItem()).toInt());
-	if (dev_symbol[0]->isChecked() && XDevice::SYMBOLSET_DIN40900 != XDevice::getSymbolSet()) {
-		XDevice::setSymbolSet(XDevice::SYMBOLSET_DIN40900);
+	Global::Device::setSize(value.toInt());
+	if (cb_display_name->isChecked()) Global::Device::setDisplayNames(true);
+	else Global::Device::setDisplayNames(false);
+	if (cb_ext_width->isChecked()) Global::Device::setWidth(3);
+	else Global::Device::setWidth(2);
+	Global::Device::setUndefinedValue(curr_undef);
+	Global::Device::setInverted(curr_invert);
+	Global::Device::setClock(curr_clk);
+	Global::Device::setFontFamily(cb_font_type->text(cb_font_type->currentItem()));
+	Global::Device::setFontSize(cb_font_size->text(cb_font_size->currentItem()).toInt());
+	if (dev_symbol[0]->isChecked() && Global::Device::SYMBOLSET_DIN40900 != Global::Device::getSymbolSet()) {
+		Global::Device::setSymbolSet(Global::Device::SYMBOLSET_DIN40900);
 		parent->setToolbarPixmap();
 	}
-	if (dev_symbol[1]->isChecked() && XDevice::SYMBOLSET_IEC617 != XDevice::getSymbolSet()) {
-		XDevice::setSymbolSet(XDevice::SYMBOLSET_IEC617);
+	if (dev_symbol[1]->isChecked() && Global::Device::SYMBOLSET_IEC617 != Global::Device::getSymbolSet()) {
+		Global::Device::setSymbolSet(Global::Device::SYMBOLSET_IEC617);
 		parent->setToolbarPixmap();
 	}
 
-	if (invert_trigger->isChecked())
-		Device::invertTrigger(1);
-	else
-		Device::invertTrigger(0);
 	value = stepTime->text();
 	if (value.toInt() != NetWidget::simTime()) {
 		NetWidget::setSimTime(value.toInt());
@@ -361,9 +349,9 @@ void PropGlob::invertedChange(int newi)
 	curr_invert = newi;
 }
 
-void PropGlob::clockChange(int clk)
+void PropGlob::clockChange(int iIntClock)
 {
-	curr_clk = clk;
+	curr_clk = (Global::Device::CLOCKTYPE)iIntClock;
 }
 
 void PropGlob::fontChange(int fnt)
