@@ -8,7 +8,7 @@ class QPushButton;
 class KLineEdit;
 
 class NetWidget;
-class XDeviceNet;
+class Circuit;
 class XDevice;
 
 class PropName : public QDialog
@@ -16,7 +16,7 @@ class PropName : public QDialog
     Q_OBJECT
 
 public:
-    PropName(QWidget *, QString, NetWidget *, XDeviceNet *, XDevice *);
+    PropName(QWidget *, QString, NetWidget *, Circuit *, XDevice *);
 
 private:
     void done(int);
@@ -26,7 +26,7 @@ private:
     KLineEdit *devname;
     QLabel *label0;
     XDevice *dev;
-    XDeviceNet *dnet;
+    Circuit *dnet;
     NetWidget *netw;
 };
 
