@@ -53,7 +53,7 @@ PropOsz::PropOsz(QWidget *parent, const char *name, Circuit *_dnet, XDevice *_de
 
 	cb_type = new QCheckBox(i18n("Monoflop"), this);
 	cb_type->setGeometry(105, 100, 90, 15);
-	if (dev->clock() == OscillatorDevice::CLK_MONO) {
+	if (dev->getOscType() == OscillatorDevice::TYPE_MONO) {
 		cb_type->setChecked(TRUE);
 		offCnt->setEnabled(FALSE);
 	} else {
@@ -108,8 +108,10 @@ void PropOsz::done(int r)
 			ivalue = OscillatorDevice::MAXOSCCNT;
 		if (ivalue < 1) ivalue = 1;
 		dev->setOszOff(ivalue);
-		if (dev->clock() == OscillatorDevice::CLK_MONO && !cb_type->isChecked()) dev->setClock(OscillatorDevice::CLK_MULTI);
-		if (dev->clock() == OscillatorDevice::CLK_MULTI && cb_type->isChecked()) dev->setClock(OscillatorDevice::CLK_MONO);
+		if (dev->getOscType() == OscillatorDevice::TYPE_MONO && !cb_type->isChecked())
+			dev->setOscType(OscillatorDevice::TYPE_MULTI);
+		if (dev->getOscType() == OscillatorDevice::TYPE_MULTI && cb_type->isChecked())
+			dev->setOscType(OscillatorDevice::TYPE_MONO);
 	}
 	QDialog::done(r);
 }
