@@ -64,11 +64,11 @@ void PropPwr::done(int r)
 	if (r == Accepted) {
 		dnet->setName(dev->getID(), devname->text());
 		if (rbPlus->isChecked()) {
-			dev->setStaticInput(1);
+			dev->setInputValue(1);
 			dev->setImage();
 		}
 		else {
-			dev->setStaticInput(0);
+			dev->setInputValue(0);
 			dev->setImage();
 		}
 	}
