@@ -13,7 +13,7 @@ class PropPwr : public QDialog
     Q_OBJECT
 
 public:
-    PropPwr(QWidget *, const char *, XDeviceNet *, XDevice *);
+    PropPwr(QWidget *, const char *, Circuit *, XDevice *);
 
 private:
     void done(int);
@@ -25,7 +25,7 @@ private:
     QButtonGroup *bgPwr;
     QRadioButton *rbPlus;
     QRadioButton *rbMinus;
-    XDeviceNet *dnet;
+    Circuit *dnet;
     XDevice *dev;
 };
 
