@@ -110,11 +110,11 @@ void PropSwitch::done(int r)
 		}
 
 		if (rbSwitch->isChecked()) {
-			dev->setToggle(true);
-		} else {
 			dev->setToggle(false);
-			if (rbHigh->isChecked()) dev->setStaticInput(1);
-			else dev->setStaticInput(0);
+		} else {
+			dev->setToggle(true);
+			if (rbHigh->isChecked()) dev->setInputValue(1);
+			else dev->setInputValue(0);
 		}
 	}
 
