@@ -4,7 +4,7 @@
 class KLineEdit;
 
 class QPushButton;
-class XDeviceNet;
+class Circuit;
 class XDevice;
 
 class PropText : public QDialog
@@ -12,7 +12,7 @@ class PropText : public QDialog
     Q_OBJECT
 
 public:
-    PropText(QWidget *, const char *, XDeviceNet *, XDevice *);
+    PropText(QWidget *, const char *, Circuit *, XDevice *);
 
 private:
     void done(int);
@@ -20,7 +20,7 @@ private:
     QPushButton *bOK;
     QPushButton *bCancel;
     KLineEdit *devtext;
-    XDeviceNet *dnet;
+    Circuit *dnet;
     XDevice *dev;
 };
 
