@@ -7,6 +7,18 @@ using namespace std;
 
 #include <qstring.h>
 
+class Referenced
+{
+public:
+	Referenced();
+	virtual ~Referenced();
+
+	int addRef() const;
+	int relRef() const;
+private:
+	mutable int m_iRef;
+};
+
 class BitSet: public set<int>
 {
 public:
