@@ -1,11 +1,10 @@
 #ifndef __COMMON_CLASSES__
 #define __COMMON_CLASSES__
 
-#include <fifo.h>
 #include <qstring.h>
 
-#define NUMBER		6
-#define THIS		5
+#include "klogic.h"
+#include "fifo.h"
 
 class OutputInfo;
 class Value;
@@ -15,10 +14,16 @@ class DelayedValue;
 class OutputInfo
 {
 public:
-	OutputInfo() { device_id = 0; output_id = 0; };
-	~OutputInfo() {};
+	OutputInfo()
+	{
+		device_id = 0;
+		output_id = 0;
+		output_type = Global::Device::NOTYPE;
+	}
 
-	QString getOutputName()
+	~OutputInfo() {}
+
+	QString getOutputName() const
 	{
 		int pos = output_name.findRev('.');
 		if (pos >= 0) {
@@ -39,7 +44,7 @@ public:
 	QString output_name;
 	QString original_output_name;
 
-	int output_type;
+	Global::Device::IOTYPE output_type;
 	QString prefix;		// object prefix
 	QString suffix;		// output name extension: "(final)"|"(intern)"
 };
@@ -50,7 +55,6 @@ class Value
 public:
 	Value() {
 		internal = false;
-		position = 0;
 		result = 0;
 		undefined_result = 0;
 		tristate = false;
@@ -61,7 +65,7 @@ public:
 		result = val;
 	}
 
-	inline int getValue() {
+	inline int getValue() const {
 		return result;
 	}
 
@@ -70,30 +74,21 @@ public:
 		internal = val;
 	}
 
-	inline bool isInternal() {
+	inline bool isInternal() const {
 		return internal;
 	}
 
 	// -----------------------------------
-	inline void setPosition(int newpos) {
-		position = newpos;
-	}
-
-	inline int getPosition() {
-		return position;
-	}
-
-	// -----------------------------------
-	inline void setUndefined(int _undef) {
+	inline void setUndefinedValue(int _undef) {
 		undefined_result = _undef;
 	}
 
-	inline int getUndefined() {
+	inline int getUndefinedValue() const {
 		return undefined_result;
 	}
 
 	// -----------------------------------
-	inline bool isTristate() {
+	inline bool isTristate() const {
 		return tristate;
 	}
 	 
@@ -106,7 +101,6 @@ protected:
 	int result;
 
 private:
-	int position;
 	bool internal;
 	bool tristate;
 };
@@ -126,7 +120,7 @@ public:
 	}
 
 	// return delayed result
-	inline int getResult() {
+	inline int getResult() const {
 		return delayed_result;
 	}
 
