@@ -12,12 +12,15 @@
 class Wire
 {
 public:
+	typedef enum IO_TYPE {INPUT, OUTPUT, BOTH};
+
 	Wire();
 	Wire(QPoint);
-	~Wire();
+	virtual ~Wire();
 
 	// draw wire
 	void drawImage(QPainter *);
+	void drawConnections(QPainter *, IO_TYPE, int = 0);
 	void setColor(QColor);
 
 	// called by XDevice
@@ -31,7 +34,7 @@ public:
 	// get io-position of connected wire
 	QPoint getIOPosition(int idx, int selonly = 0);
 
-	// called by NetDevice
+	// called by NetWidget
 	void garbageCollection();
 	QPoint getActive();
 	int activeIsInput();
@@ -41,13 +44,15 @@ public:
 	int lockNode(QPoint);
 	bool lockLastNode();
 	int lockSelectedNode();
+	void updateNode(QPoint);	// update position of active node
+	void releaseNode();
 
 	// called by Selection
 	int getMinSelX();
 	int getMaxSelX();
 	int getMinSelY();
 	int getMaxSelY();
-	void addPos(int, int);
+	void moveBy(const QPoint&);
 	bool isSelected();
 
 	// constants
@@ -74,6 +79,7 @@ protected:
 	// draw grid into rect
 	void restoreArry(QPainter *p, int, int, int, int);
 	void drawSolderedPoint(QPainter *, QColor, QPoint);
+	void drawInverterPoint(QPainter *, QColor, QPoint);
 
 	// wire modifying methods
 	KlogicList<QPoint> *contains(QPoint);
@@ -87,10 +93,8 @@ protected:
 
 	// operations on active (locked) node
 	int createNode(const QPoint&);	// set active node
-	void updateNode(QPoint);	// update position of active node
 	void cutNode();			// will not destroy it!
 	void removeNode();		// destroys active node
-	void releaseNode();
 	QPoint *getActiveNode();
 	bool activeIsReference();	// node is only a copy
 	bool activeIsForeign();		// also part of another wire
@@ -110,7 +114,7 @@ protected:
 	void unselect();
 
 	// current color of the wire
-	QColor color;
+	QColor m_oColor;
 
 	// set wire size in pixels
 	void setLineSize(int);
@@ -119,6 +123,9 @@ protected:
 	void enforceCompleteDrawing();
 	bool completeDrawingIsEnforced();
 
+	virtual bool inputIsInverted(int) { return false; }
+	virtual bool outputIsInverted(int) { return false; }
+
 private:
 	// *****************************************************
 	// import/export
@@ -139,16 +146,16 @@ private:
 	// connection management
 	// *****************************************************
 	// node of wire, which is input-node (input of a device)
-	QPoint *input[2];
+	QPoint *m_poInputNode[2];
 
 	// node of wire, which is output-node (output of a device)
-	QPoint *output[2];
+	QPoint *m_poOutputNode[2];
 
 	// connection nodes (wire-wire-connections)
-	QPoint *io_point[2];
+	QPoint *m_poWireNode[2];
 
 	// connection nodes of other wires (references)
-	KlogicList<QPoint> io_point_foreign;
+	KlogicList<QPoint> m_oForeignWireNodes;
 
 	// *****************************************************
 	// moving and drawing management
@@ -176,8 +183,8 @@ private:
 	// all currenty selected nodes of this wire
 	KlogicList<QPoint> selnode;
 
-	int size;
-	int old_size;
+	int m_iSize;
+	int m_iOldSize;
 };
 
 #endif
