@@ -8,6 +8,7 @@
 #include "circuit.h"
 #include "xdevice.h"
 #include "deviceTypes.h"
+#include "deviceOsc.h"
 #include "xwire.h"
 #include "xmlExport.h"
 #include "xmlImport.h"
@@ -52,7 +53,7 @@ void XmlObject::createXML(bool)
 
 // return value can be both, a circuit or a device
 // use XDevice::devIsNet() to retrieve Circuit pointer from XDevice
-XDevice * XmlObject::createInstance(Circuit *_net, int dx, int dy)
+XDevice * XmlObject::createInstance(Circuit *poCircuit, int dx, int dy)
 {
 	QString content = getField();
 
@@ -64,7 +65,7 @@ XDevice * XmlObject::createInstance(Circuit *_net, int dx, int dy)
 	f.close();
 	f.open(IO_ReadOnly);
 	QTextStream ts2(&f);
-	return XMLImportHandler::import(_net, dx, dy, ts2);
+	return XMLImportHandler::import(poCircuit, dx, dy, ts2);
 }
 
 void XmlObject::setValid(bool __valid)
@@ -87,34 +88,34 @@ bool XmlObject::isValid()
 /*                                         */
 /* Andreas Rostin 24.08.2001               */
 /*******************************************/
-XmlNet::XmlNet(Circuit *_net, bool selected, int level, int dx, int dy)
+XmlNet::XmlNet(Circuit *poCircuit, bool selected, int level, int dx, int dy)
 	: XmlObject(XmlSymbolMap::m_oMap[XmlSymbol::CIRCUIT], level, dx, dy)
 {
-	net = _net;
+	m_poCircuit = poCircuit;
 	createXML(selected);
 }
 
 XmlNet::XmlNet()
 	: XmlObject(XmlSymbolMap::m_oMap[XmlSymbol::CIRCUIT], 0, 0, 0)
 {
-	net = (Circuit *)NULL;
+	m_poCircuit = (Circuit *)NULL;
 }
 
 void XmlNet::createXML(bool selected)
 {
-	if (selected && !net->isSelected()) return;
+	if (selected && !m_poCircuit->isSelected()) return;
 	setValid(true);
-	setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::ID], net->getID());
-	addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::FUNCTION], net->type());
-	addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::SIZE], net->size());
-	int x = net->getPos().x() - net->getHOffset() - dx;
+	setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::ID], m_poCircuit->getID());
+	addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::FUNCTION], m_poCircuit->type());
+	addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::SIZE], m_poCircuit->size());
+	int x = m_poCircuit->getPos().x() - m_poCircuit->getHOffset() - dx;
 	if (x < 0) x = 0;
-	int y = net->getPos().y() + net->getVOffset() - dy;
+	int y = m_poCircuit->getPos().y() + m_poCircuit->getVOffset() - dy;
 	if (y < 0) y = 0;
 	addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::XPOS], x);
 	addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::YPOS], y);
 
-	XmlDevice dev(net, selected, -1, dx, dy);
+	XmlDevice dev(m_poCircuit, selected, -1, dx, dy);
 	setContent(dev.getFieldContent());
 }
 
@@ -299,23 +300,18 @@ void XmlDevice::createXML(bool selected)
 	field.set(XmlSymbolMap::m_oMap[XmlSymbol::TEXT], XmlField::quote(text));
 	addContent(field.getField());
 
-	if (dev->nameDisplayed()) {
+	if (dev->nameDisplayed() != Global::Device::DEFAULT_DISPLAY_NAMES) {
 		field.set(XmlSymbolMap::m_oMap[XmlSymbol::TEXT_DISP], "");
 		addContent(field.getField());
 	}
 
-	if (dev->type() != DeviceType::fNET &&
-	    dev->type() != DeviceType::fLEDred &&
-	    dev->type() != DeviceType::fLEDblue &&
-	    dev->type() != DeviceType::fLEDgreen &&
-	    dev->type() != DeviceType::fLEDyellow &&
-	    dev->delay() != Device::DEFAULT_DELAY) { 
-		field.set(XmlSymbolMap::m_oMap[XmlSymbol::DELAY], dev->delay());
+	if (dev->getDelay() != Global::Device::DEFAULT_DELAY) { 
+		field.set(XmlSymbolMap::m_oMap[XmlSymbol::DELAY], dev->getDelay());
 		addContent(field.getField());
 	}
 
-	if (dev->undef() != Device::DEFAULT_UNDEF) { 
-		field.set(XmlSymbolMap::m_oMap[XmlSymbol::UNDEF], dev->undef());
+	if (dev->getUndefinedValue() != Global::Device::DEFAULT_UNDEFINED_VALUE) { 
+		field.set(XmlSymbolMap::m_oMap[XmlSymbol::UNDEF], dev->getUndefinedValue());
 		addContent(field.getField());
 	}
  
@@ -325,7 +321,7 @@ void XmlDevice::createXML(bool selected)
 	}
  
 	// flipflop properties
-	if (dev->type() != DeviceType::fOSC && dev->hasClock()) {
+	if (dev->hasClock()) {
 		field.set(XmlSymbolMap::m_oMap[XmlSymbol::CLK_TYPE], dev->clock());
 		addContent(field.getField());
 
@@ -334,34 +330,34 @@ void XmlDevice::createXML(bool selected)
 	}
 
 	// switch properties
-	if (dev->type() == DeviceType::fSWI && dev->isToggle()) {
+	if (dev->isToggle()) {
 		field.set(XmlSymbolMap::m_oMap[XmlSymbol::PUSH]);
 		addContent(field.getField());
 	}
 
-	// width property: possible only for equ, net
-	if ((dev->type() == DeviceType::fEQU || dev->type() == DeviceType::fNET) && dev->width() != XDevice::DEFAULT_WIDTH) {
+	// width property: possible only for equ, circuit
+	if (dev->width() != Global::Device::DEFAULT_WIDTH) {
 		field.set(XmlSymbolMap::m_oMap[XmlSymbol::WIDTH], dev->width());
 		addContent(field.getField());
 	}
 
 	// default inverted output
-	if (dev->isInverted()) {
+	if (dev->isInverted() != Global::Device::DEFAULT_INVERTED) {
 		field.set(XmlSymbolMap::m_oMap[XmlSymbol::INV]);
 		addContent(field.getField());
 	}
 
 	// oscillator properties
 	if (dev->type() == DeviceType::fOSC) {
-		field.set(XmlSymbolMap::m_oMap[XmlSymbol::CLK_TYPE], dev->clock());
+		field.set(XmlSymbolMap::m_oMap[XmlSymbol::CLK_TYPE], dev->getOscType());
 		addContent(field.getField());
 
-		if (dev->oszOn() != Device::DEFAULT_OSC_CNT) {
+		if (dev->oszOn() != OscillatorDevice::DEFAULT_OSC_PERIOD) {
 			field.set(XmlSymbolMap::m_oMap[XmlSymbol::OSC_ON], dev->oszOn());
 			addContent(field.getField());
 		}
 	 
-		if (dev->oszOff() != Device::DEFAULT_OSC_CNT) {
+		if (dev->oszOff() != OscillatorDevice::DEFAULT_OSC_PERIOD) {
 			field.set(XmlSymbolMap::m_oMap[XmlSymbol::OSC_OFF], dev->oszOff());
 			addContent(field.getField());
 		}
@@ -377,42 +373,45 @@ void XmlDevice::createXML(bool selected)
 	}
 
 	// named output
-	if ((dev->type() == DeviceType::fEQU || dev->type() == DeviceType::fNET) && dev->hasNamedOutput()) {
-		KlogicList<Calculator> *lo = dev->getNamedORef()->First()->Next();
-		while (lo) {
+	if (dev->hasNamedOutput()) {
+		ConnectorList::iterator iter = dev->getNamedOutputIterator();
+		iter++;
+		while (iter != dev->getNamedOutputEndIterator()) {
+			Connector& oConnector = *iter;
+			Calculator *poCalculator = *oConnector;
 			if (dev->type() == DeviceType::fEQU) {
-				text = lo->Get()->getEquation();
+				text = poCalculator->getEquation();
 				field.set(XmlSymbolMap::m_oMap[XmlSymbol::OUT_EQU], XmlField::quote(text));
-				field.setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::POS], lo->Get()->getPosition());
-				field.addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::INTERN], lo->Get()->isInternal());
-				text = lo->getText();
+				field.setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::POS], oConnector.getPosition());
+				field.addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::INTERN], poCalculator->isInternal());
+				text = oConnector.getName();
 				field.addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::NAME], XmlField::quote(text));
 			} else {
-				field.set(XmlSymbolMap::m_oMap[XmlSymbol::OUT_ID], lo->getID1());
-				field.setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::POS], lo->Get()->getPosition());
+				field.set(XmlSymbolMap::m_oMap[XmlSymbol::OUT_ID], oConnector.getConnectorID());
+				field.setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::POS], oConnector.getPosition());
 			}
 
 			addContent(field.getField());
-			lo = lo->Next();
+			iter++;
 		}
 	}
 
 	// named input 
-	if ((dev->type() == DeviceType::fEQU || dev->type() == DeviceType::fNET) && dev->hasNamedInput()) {
-		KlogicList<Value> *li = dev->getNamedIRef()->First();
-		while(li) {
+	if (dev->hasNamedInput()) {
+		ConnectorList::iterator iter = dev->getNamedInputIterator();
+		while (iter != dev->getNamedInputEndIterator()) {
+			Connector& oConnector = *iter;
 			if (dev->type() == DeviceType::fEQU) {
-				text = li->getText();
+				text = oConnector.getName();
 				field.set(XmlSymbolMap::m_oMap[XmlSymbol::IN_NAME], XmlField::quote(text));
-				field.setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::POS], li->Get()->getPosition());
-				field.addAttribute(XmlSymbolMap::m_oMap[XmlSymbol::INTERN], li->Get()->isInternal());
+				field.setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::POS], oConnector.getPosition());
 			} else {
-				field.set(XmlSymbolMap::m_oMap[XmlSymbol::IN_ID], li->getID1());
-				field.setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::POS], li->Get()->getPosition());
+				field.set(XmlSymbolMap::m_oMap[XmlSymbol::IN_ID], oConnector.getConnectorID());
+				field.setAttribute(XmlSymbolMap::m_oMap[XmlSymbol::POS], oConnector.getPosition());
 			}
 
 			addContent(field.getField());
-			li = li->Next();
+			iter++;
 		}
 	}
 
@@ -427,5 +426,11 @@ void XmlDevice::createXML(bool selected)
 		field.set(XmlSymbolMap::m_oMap[XmlSymbol::BUSTYPE], dev->isMux());
 		addContent(field.getField());
 	}
+
+	// color (LED devices)
+	if (dev->getColor()) {
+		field.set(XmlSymbolMap::m_oMap[XmlSymbol::COLOR], dev->getColor());
+		addContent(field.getField());
+	}
 }
 
