@@ -353,10 +353,16 @@ int XWire::connectOutput(XDevice *dev, int invert, int device_id)
 	out_dev[idx] = dev;
 	out_id[idx] = device_id;
 
-	if (dev->outputIsInvertedAt(Wire::getActive())) output_is_inv[idx] = 1;
-	else if (invert == 1) output_is_inv[idx] = 1;
-	else if (invert == -1) output_is_inv[idx] = 0;
-	else output_is_inv[idx] = out_dev[idx]->isInverted();
+	// detemination of invertation - use default only if no file import is running currently
+	if (!Device::IMPORT_IGNORE_GLOBAL) {
+		if (dev->outputIsInvertedAt(Wire::getActive())) output_is_inv[idx] = 1;
+		else if (invert == 1) output_is_inv[idx] = 1;
+		else if (invert == -1) output_is_inv[idx] = 0;
+		else output_is_inv[idx] = out_dev[idx]->isInverted();
+	} else {
+		if (invert == 1) output_is_inv[idx] = 1;
+		else output_is_inv[idx] = 0;
+	}
 
 	// add reference to this wire in device
 	out_dev[idx]->addOutputWire(this);
